import React from "react";
import PropTypes from "prop-types";
import { createMaterialTopTabNavigator } from "@react-navigation/material-top-tabs";
import RouteEditionsDate from "../models/route-editions-date";
import RouteEdition from "../models/route-edition";
import EditionsNested from "../components/EditionsNested/editions-nested";
import EditionItem from "../components/EditionItem/edition-item";
import EditionDayPage from "../components/EditionDayPage/edition-day-page";

const Tab = createMaterialTopTabNavigator();

function renderTabScreens({ routes, props = {} }) {
    const screens = [];
    routes.forEach((route) => {
        let Component = null;
        if (route instanceof RouteEditionsDate) {
            Component = (
                <Tab.Screen name={route.getText()} key={route.getRoute()}>
                    {(navProps) => <EditionDayPage edition={route.getEdition()} {...props} {...navProps} />}
                </Tab.Screen>
            );
        } else if (route instanceof RouteEdition) {
            Component = (
                <Tab.Screen name={route.getText()} key={route.getRoute()}>
                    {(navProps) => <EditionsNested main={route.getEdition()} {...props} {...navProps} />}
                </Tab.Screen>
            );
        }

        if (Component) {
            screens.push(Component);
        }
    });
    return screens;
}

function TabNavigator(props) {
    const { routes, specials, issueCallbacks } = props;

    return <Tab.Navigator>{renderTabScreens({ routes, props: { specials, issueCallbacks } })}</Tab.Navigator>;
}

TabNavigator.propTypes = {
    routes: PropTypes.array,specials: PropTypes∂.array, 
    issueCallbacks: EditionItem.propTypes.issueCallbacks
};
export default TabNavigator;
