import React from "react";
import { Calendar, LocaleConfig } from "react-native-calendars";
import LiveConfig from "../../data/live-config";
import DateUtils from "../../utils/date";
import Logger from "../../utils/log";
import IcArrowLeft from "../Icon/ic-arrow-left";
import IcArrowRight from "../Icon/ic-arrow-right";
import CalendarCommons from "./calendar-common";

function TaCalendar(props) {
    const { date, minDate, maxDate, onDateChange, markedDates } = props;

    //markedDates
    const onChange = ({ timestamp }) => {
        if (typeof onDateChange === "function") {
            onDateChange(new Date(timestamp));
        }
    };

    const others = {};
    if (minDate) {
        others.minDate = DateUtils.getDateString(minDate, "YYYY-MM-DD");
    }
    if (maxDate) {
        others.maxDate = DateUtils.getDateString(maxDate, "YYYY-MM-DD");
    }
    if (date) {
        others.current = DateUtils.getDateString(date, "YYYY-MM-DD");
    }

    if (markedDates) {
        others.markedDates = markedDates.reduce((result, { date: markedDate, ...rest }) => {
            result[DateUtils.getDateString(markedDate, "YYYY-MM-DD")] = rest;
            return result;
        });
    }

    const locale = LiveConfig.getLocale();
    /*LocaleConfig.locales['fr'] = {
        monthNames: [
          'Janvier',
          'Février',
          'Mars',
          'Avril',
          'Mai',
          'Juin',
          'Juillet',
          'Août',
          'Septembre',
          'Octobre',
          'Novembre',
          'Décembre'
        ],
        monthNamesShort: ['Janv.', 'Févr.', 'Mars', 'Avril', 'Mai', 'Juin', 'Juil.', 'Août', 'Sept.', 'Oct.', 'Nov.', 'Déc.'],
        dayNames: ['Dimanche', 'Lundi', 'Mardi', 'Mercredi', 'Jeudi', 'Vendredi', 'Samedi'],
        dayNamesShort: ['Dim.', 'Lun.', 'Mar.', 'Mer.', 'Jeu.', 'Ven.', 'Sam.'],
        today: "Aujourd'hui"
      };*/
    Logger.debug(locale.getLanguage());
    LocaleConfig.defaultLocale = locale.getLanguage();

    return (
        <Calendar
            {...others}
            hideExtraDays
            renderArrow={(direction) => {
                if (direction === "left") {
                    return <IcArrowLeft width={16} />;
                }
                return <IcArrowRight width={16} />;
            }}
            hideArrows={false}
            onDayPress={onChange}
        />
    );
}

TaCalendar.propTypes = {
    ...CalendarCommons.propTypes
};

TaCalendar.defaultProps = {
    ...CalendarCommons.defaultProps
};

export default TaCalendar;
