import { Platform, StyleSheet } from "react-native";
import { colors } from "../../utils/colors";

const DRAWER_PERMANENT = 800;
const DRAWER_WIDTH = 250;
const SHADOW_HEIGHT = 1;
const CARD_PADDING = 10;
const CARD_MARGIN = 10;
const CARD_RADIUS = 10;
const HEADER_HEIGHT = 50;
const ANIMATION_DURATION = 300;
const MAIN_VIEW_PADDING = 30;
const MAIN_ISSUE_MAX_WIDTH = 600;
const ISSUE_MIN_WIDTH = 100;
const MAX_SCREEN_WIDTH = 800;

const NEW_LINE = "<br>";

const commonStyles = StyleSheet.create({
    container: {
        flex: 1
    },
    background: {
        backgroundColor: "rgb(242,242,242)"
    },
    full: {
        position: "absolute",
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        overflow: "visible"
    },
    noShadow: {
        elevation: 0,
        shadowOffset: {
            width: 0,
            height: 0
        }
    },
    noMargin: {
        margin: 0
    },
    noPadding: {
        padding: 0
    },
    shadow: {
        ...Platform.select({
            android: {
                elevation: 2
            },
            default: {
                shadowColor: colors.black,
                shadowOffset: { width: 1, height: SHADOW_HEIGHT },
                shadowOpacity: 0.1,
                shadowRadius: 1
            }
        })
    },
    fullShadow: {
        ...Platform.select({
            android: {
                elevation: 2
            },
            default: {
                shadowColor: colors.black,
                shadowOffset: { width: 0, height: 1 },
                shadowOpacity: 0.5,
                shadowRadius: 3
            }
        }),
        backgroundColor: Platform.select({
            ios: colors.transparent,
            default: colors.white
        })
    },
    darkShadow: {
        ...Platform.select({
            android: {
                elevation: 1
            },
            default: {
                zIndex: 1,
                shadowColor: colors.black,
                shadowOffset: { width: 0, height: 2 },
                shadowOpacity: 0.5,
                shadowRadius: 5
            }
        })
    },
    darkThickShadow: {
        ...Platform.select({
            android: {
                elevation: 1
            },
            default: {
                shadowColor: colors.black,
                shadowOffset: { width: 0, height: 5 },
                shadowOpacity: 0.5,
                shadowRadius: 1
            }
        })
    },
    shadowReset: {
        ...Platform.select({
            android: {
                //elevation: 0
            },
            default: {
                shadowColor: colors.transparent,
                shadowOffset: { width: 0, height: 0 },
                shadowOpacity: 0,
                shadowRadius: 0
            }
        })
    },
    selfCenter: {
        alignSelf: "center"
    },
    center: {
        textAlign: "center"
    },
    card: {
        backgroundColor: colors.white,
        borderRadius: CARD_RADIUS,
        padding: CARD_PADDING,
        margin: CARD_MARGIN
    },
    modalContent: {
        backgroundColor: colors.white,
        borderRadius: CARD_RADIUS,
        padding: CARD_PADDING,
        margin: CARD_MARGIN,
        overflow: "hidden"
    },
    margin: {
        margin: CARD_MARGIN / 2
    },
    radius: {
        borderRadius: CARD_RADIUS
    }
});

export {
    NEW_LINE,
    commonStyles,
    DRAWER_WIDTH,
    DRAWER_PERMANENT,
    CARD_MARGIN,
    CARD_PADDING,
    CARD_RADIUS,
    HEADER_HEIGHT,
    ANIMATION_DURATION,
    MAIN_VIEW_PADDING,
    ISSUE_MIN_WIDTH,
    MAIN_ISSUE_MAX_WIDTH,
    MAX_SCREEN_WIDTH
};
