import React from "react";
import PropTypes from "prop-types";
import { StyleSheet, TouchableOpacity } from "react-native";
import ColorUtils, { colors } from "../../utils/colors";
import { Css } from "../Css/css";
import TaImageIcon from "../Tecnavia/ta-image-icon";
import TaText from "../Tecnavia/ta-text";
import Route from "../../models/route";
import LiveConfig from "../../data/live-config";

const styles = StyleSheet.create({
    container: {
        flex: 1,
        alignItems: "center",
        flexDirection: "row"
    },
    text: {
        color: colors.black,
        fontSize: 20,
        flex: 1,
        paddingHorizontal: 5
    },
    icon: {
        height: 30,
        width: 30,
        marginHorizontal: 5
    }
});

function DrawerItemLeft(props) {
    const { route, onPress, active } = props;
    return (
        <Css classes={["opt-drawer-item-touchable"]} cssKey={route.getRoute()}>
            <TouchableOpacity style={styles.container} onPress={onPress}>
                <Css classes={["opt-drawer-icon"]} cssKey={route.getRoute()}>
                    <TaImageIcon
                        source={{ uri: route.getIcon() }}
                        style={route.getIcon() && styles.icon}
                        resizeMode="contain"
                    />
                </Css>
                <Css classes={["opt-drawer-item-text"]} cssKey={route.getRoute()}>
                    <TaText
                        style={[
                            styles.text,
                            active && { color: ColorUtils.determineTextColor(LiveConfig.getSupportColor()) }
                        ]}>
                        {route.getText()}
                    </TaText>
                </Css>
            </TouchableOpacity>
        </Css>
    );
}

DrawerItemLeft.propTypes = {
    route: PropTypes.instanceOf(Route),
    onPress: PropTypes.func,
    active: PropTypes.bool
};

export default DrawerItemLeft;
