import React, { useCallback } from "react";
import PropTypes from "prop-types";
import { StyleSheet } from "react-native";
import { DrawerContentScrollView } from "@react-navigation/drawer";
import Route from "../../models/route";
import DrawerItemWithState from "./drawer-item";
import { Css } from "../Css/css";
import Logger from "../../utils/log";
import RouteSeparator from "../../models/route-separator";
import DrawerSeparator from "./drawer-separator";
import RouteEdition from "../../models/route-edition";
import RouteUrl from "../../models/route-url";
import RouteHeader from "../../models/route-header";
import DrawerHeader from "./drawer-header";
import RouteTabs from "../../models/route-tabs";
import Events from "../../events/events";
import { EventRegister } from "../../events/manager";

const styles = StyleSheet.create({
    scroll: {
        flex: 1
    },
    scrollContent: {
        paddingTop: 0
    }
});

function DrawerContent(props) {
    const { navigation, routes } = props;

    const onPress = useCallback((route: Route) => {
        try {
            if (route instanceof RouteUrl && route.getTarget() === "_blank") {
                EventRegister.emit(Events.ON_EXTERNAL_LINK_CLICK, { url: route.getUrl() });
            } else {
                navigation.navigate(route.getRoute());
            }
        } catch (e) {
            Logger.warn(e.message);
        }
    }, []);

    return (
        <Css classes={["opt-drawer-container"]}>
            <DrawerContentScrollView style={styles.scroll} contentContainerStyle={styles.scrollContent}>
                {routes.map((route, index) => {
                    if (route instanceof RouteSeparator) {
                        return <DrawerSeparator key={`drawer_separator_${index}`} route={route} />;
                    }
                    if (route instanceof RouteHeader) {
                        return <DrawerHeader key={`drawer_header_${index}_${route.getHeader()}`} route={route} />;
                    }
                    if (route instanceof RouteEdition || route instanceof RouteUrl) {
                        return (
                            <DrawerItemWithState
                                key={`drawer_item_${route.getRoute()}`}
                                onPress={onPress}
                                route={route}
                                navigation={navigation}
                            />
                        );
                    }
                    if (route instanceof RouteTabs) {
                        return (
                            <DrawerItemWithState
                                key={`drawer_item_${route.getRoute()}`}
                                onPress={onPress}
                                route={route}
                                navigation={navigation}
                                collapsable={false}
                            />
                        );
                    }
                    return null;
                })}
            </DrawerContentScrollView>
        </Css>
    );
}

DrawerContent.propTypes = {
    routes: PropTypes.arrayOf(PropTypes.instanceOf(Route)).isRequired,
    navigation: PropTypes.object.isRequired
};

export default DrawerContent;
