import React from "react";
import { ScrollView, View } from "react-native";
import IssueList from "../List/issue-list";
import EditionMain from "../EditionMain/edition-main";
import EditionsHelper from "../../helpers/editions-helper";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import Issue from "../../models/issue";
import EditionsSecondary from "../EditionsSecondary/editions-secondary";
import { styles } from "./edition-day-page";

/**
 * manage main edition and list with specials and other issue of selected edition
 * @param {*} props
 * @returns
 */
export function EditionPage(props) {
    const { edition, specials, secondaryEditions, issueCallbacks, navigation } = props;
    const [mainIssue, ...issues] = edition.getIssues();

    /**
     * override issue press to have different behaviour instead of opening always the issue
     * @param {*} issue
     */
    const onIssuePress = (issue: Issue) => {
        //shortcut item navigate to drawer section instead of open the issue
        const found = EditionsHelper.getPublicationFromIssue(specials, issue);
        if (found && found.isShortcut()) {
            navigation.navigate(EditionsHelper.getRouteName(found.getName()));
        } else if (typeof issueCallbacks.onIssuePress === "function") {
            issueCallbacks.onIssuePress(issue);
        }
    };

    return (
        <View style={commonStyles.container}>
            <Css classes={["opt-editions-scroll"]}>
                <ScrollView nestedScrollEnabled>
                    <View style={styles.container}>
                        <View collapsable={false}>
                            <EditionMain issue={mainIssue} issueCallbacks={issueCallbacks} />
                        </View>
                        <Css classes={["opt-editions-others"]}>
                            <View style={[styles.other, styles.hOther]}>
                                <View collapsable={false}>
                                    <IssueList
                                        issues={issues}
                                        title={edition.getLabel()}
                                        issueCallbacks={issueCallbacks}
                                        horizontal
                                    />
                                </View>
                                <View collapsable={false}>
                                    <EditionsSecondary
                                        mainEditionName={edition.getName()}
                                        editions={secondaryEditions}
                                        issueCallbacks={{
                                            ...issueCallbacks,
                                            onIssuePress
                                        }}
                                        horizontal
                                    />
                                </View>
                            </View>
                        </Css>
                    </View>
                </ScrollView>
            </Css>
        </View>
    );
}
