import React, { useState } from "react";
import PropTypes from "prop-types";
import EditionDayPage from "./edition-day-page";
import { AspectRatioContext } from "../Context/context";
import RouteEditionsDate from "../../models/route-editions-date";
import EditionDaySelector from "./edition-day-selector";

/**
 * manage main edition and list with specials and other issue of selected edition
 * @param {*} props
 * @returns
 */
function EditionDayContainer(props) {
    const { main, navigation } = props;
    const [issueDayIndex, setIssueDayIndex] = useState(main.getIssueDayIndex());
    const edition = main.getEdition();
    const [mainEdition] = edition.getGroup();

    return (
        <AspectRatioContext.Consumer>
            {(value) => (
                <EditionDayPage
                    Header={
                        <EditionDaySelector
                            selector={!main.isFixed()}
                            issues={mainEdition.getIssues()}
                            issueIndex={issueDayIndex}
                            navigation={navigation}
                            onIndexChange={(index) => setIssueDayIndex(index)}
                        />
                    }
                    enableCalendarConstraint={!main.isFixed()}
                    edition={edition}
                    issueDayIndex={issueDayIndex}
                    {...props}
                    aspectRatio={value}
                />
            )}
        </AspectRatioContext.Consumer>
    );
}

EditionDayContainer.propTypes = {
    ...EditionDayPage.propTypes,
    main: PropTypes.instanceOf(RouteEditionsDate)
};

export default EditionDayContainer;
