import React from "react";
import PropTypes from "prop-types";
import { View } from "react-native";
import Issue from "../../models/issue";
import EditionItem, { THUMBNAIL_MAIN_HEIGHT, updateSize } from "../EditionItem/edition-item";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import { useAspectRatio } from "../../hooks/hooks";
import LiveConfig from "../../data/live-config";

function EditionMain(props) {
    const { issue, constraints, issueCallbacks } = props;
    const aspectRatio = useAspectRatio(issue);

    if (!aspectRatio) {
        return null;
    }

    const size = updateSize({
        height: LiveConfig.getAvailableHeight(THUMBNAIL_MAIN_HEIGHT),
        aspectRatio,
        constraints
    });
    return (
        <Css classes={["opt-editions-main"]}>
            <View style={[size, commonStyles.selfCenter]}>
                <Css classes={["opt-editions-issue-container"]}>
                    <View style={[commonStyles.card, commonStyles.shadow, commonStyles.full]}>
                        <Css classes={["opt-editions-issues"]}>
                            <EditionItem item={issue} issueCallbacks={issueCallbacks} style={commonStyles.container} />
                        </Css>
                    </View>
                </Css>
            </View>
        </Css>
    );
}

EditionMain.propTypes = {
    issue: PropTypes.instanceOf(Issue).isRequired,
    constraints: PropTypes.shape({ width: PropTypes.number, height: PropTypes.number }).isRequired,
    issueCallbacks: EditionItem.propTypes.issueCallbacks
};

export default EditionMain;
