import React, { useCallback, useState } from "react";
import PropTypes from "prop-types";
import { StyleSheet, View } from "react-native";
import Issue from "../../models/issue";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import { useAspectRatio } from "../../hooks/hooks";
import LiveConfig from "../../data/live-config";
import { updateSize, THUMBNAIL_MAIN_HEIGHT } from "../List/list-utils";
import IssueItem from "../IssueItem/issue-item";
import CssHelper from "../Css/css-methods";
import CssStyle from "../Css/css-styles";

const styles = StyleSheet.create({
    container: {
        flex: 1
    }
});

function EditionMain(props) {
    const { issue, issueCallbacks, size } = props;

    const aspectRatio = useAspectRatio(issue);
    if (!aspectRatio) {
        return null;
    }

    return (
        <Css classes={["opt-editions-main"]}>
            <View style={[size, commonStyles.selfCenter]}>
                <Css classes={["opt-editions-issue-container"]}>
                    <View style={[commonStyles.card, commonStyles.shadow, commonStyles.full]}>
                        <Css classes={["opt-editions-issues"]}>
                            <IssueItem
                                item={issue}
                                issueCallbacks={issueCallbacks}
                                style={commonStyles.container}
                                showHighRes
                            />
                        </Css>
                    </View>
                </Css>
            </View>
        </Css>
    );
}

EditionMain.propTypes = {
    issue: PropTypes.instanceOf(Issue).isRequired,
    issueCallbacks: IssueItem.propTypes.issueCallbacks
};

export default EditionMain;
