import React from "react";
import PropTypes from "prop-types";
import EditionListHorizontal from "./edition-list-horizontal";
import EditionListVertical from "./edition-list-vertical";
import { useAspectRatio } from "../../hooks/hooks";
import EditionItem, { THUMBNAIL_HEIGHT, updateSize } from "../EditionItem/edition-item";

/**
 * component that choose wich kind of list render
 * evaluate also item size by checking first issue aspect ratio and parent constraint
 * @param {*} props
 * @returns
 */
function EditionList(props) {
    const { horizontal, constraints, ...rest } = props;
    const aspectRatio = useAspectRatio(rest.issues[0]);

    if (!aspectRatio) {
        return null;
    }

    const itemSize = updateSize({ height: THUMBNAIL_HEIGHT, aspectRatio, constraints });
    return horizontal ? (
        <EditionListHorizontal itemSize={itemSize} {...rest} />
    ) : (
        <EditionListVertical itemSize={itemSize} {...rest} />
    );
}

EditionList.propTypes = {
    horizontal: PropTypes.bool,
    constraints: PropTypes.shape({ width: PropTypes.number, height: PropTypes.number }).isRequired,
    issuesCallback: EditionItem.propTypes.issueCallbacks,
    removeClippedSubviews: PropTypes.bool,
    initialNumToRender: PropTypes.number,
    showEditionName: PropTypes.bool
};

EditionList.defaultProps = {
    horizontal: true,
    initialNumToRender: 5,
    removeClippedSubviews: true,
    showEditionName: false
};

export default EditionList;
