import React, { useCallback } from "react";
import PropTypes from "prop-types";
import { StyleSheet, TouchableOpacity, View } from "react-native";
import Edition from "../../models/edition";
import TaText from "../Tecnavia/ta-text";
import { colors } from "../../utils/colors";
import TaImageIcon from "../Tecnavia/ta-image-icon";
import IcSquareRoundedOutline from "../Icon/ic-square-rounded-outline";
import IcPlus from "../Icon/ic-plus";
import { Css } from "../Css/css";

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "row",
        padding: 5,
        backgroundColor: colors.white
    },
    text: {
        fontSize: 18,
        paddingHorizontal: 5
    },
    badge: {
        fontSize: 15,
        padding: 5,
        width: 30,
        height: 30,
        borderRadius: 50,
        backgroundColor: colors.md_blue_800,
        color: colors.white,
        textAlign: "center"
    },
    image: {
        width: 24,
        height: 24
    },
    selected: {
        position: "absolute",
        top: 2,
        left: 2,
        width: 20,
        height: 20
    }
});
function EditionsSecondaryItemText(props) {
    const { edition, selected, onPress }: { edition: Edition } = props;
    const onCheckboxPress = useCallback(() => {
        if (typeof onPress === "function") {
            onPress(edition);
        }
    });
    return (
        <Css classes={["opt-editions-secondary-item-container"]}>
            <View style={styles.container}>
                <Css classes={["opt-editions-secondary-item-touchable"]}>
                    <TouchableOpacity onPress={onCheckboxPress}>
                        <Css classes={["opt-editions-secondary-item-empty-checkbox-image"]}>
                            <TaImageIcon
                                style={styles.image}
                                DefaultComponent={
                                    <Css classes={["opt-editions-secondary-item-empty-checkbox-svg"]}>
                                        <IcSquareRoundedOutline style={styles.image} />
                                    </Css>
                                }
                            />
                        </Css>
                        {selected ? (
                            <Css classes={["opt-editions-secondary-item-selected-image"]}>
                                <TaImageIcon
                                    style={styles.selected}
                                    DefaultComponent={
                                        <Css classes={["opt-editions-secondary-item-selected-svg"]}>
                                            <IcPlus style={styles.selected} width={20} height={20} />
                                        </Css>
                                    }
                                />
                            </Css>
                        ) : null}
                    </TouchableOpacity>
                </Css>
                <Css classes={["opt-editions-secondary-item-text"]}>
                    <TouchableOpacity onPress={onCheckboxPress}>
                        <TaText style={styles.text}>{edition.getLabel()}</TaText>
                    </TouchableOpacity>
                </Css>
                {/*<TaText style={styles.badge}>{edition.getIssues().length}</TaText>*/}
            </View>
        </Css>
    );
}

EditionsSecondaryItemText.propTypes = {
    edition: PropTypes.instanceOf(Edition).isRequired,
    selected: PropTypes.bool,
    onPress: PropTypes.func
};

EditionsSecondaryItemText.defaultProps = {
    selected: false
};

export default EditionsSecondaryItemText;
