import React from "react";
import PropTypes from "prop-types";
import { StyleSheet, TouchableOpacity, View } from "react-native";
import { HEADER_HEIGHT } from "../Css/common-styles";
import TaText from "../Tecnavia/ta-text";
import { colors } from "../../utils/colors";
import TaImageIcon from "../Tecnavia/ta-image-icon";
import IcClose from "../Icon/ic-close";
import { Css } from "../Css/css";
import IcContentSaveOutline from "../Icon/ic-content-save-outline";
import LiveConfig from "../../data/live-config";

const styles = StyleSheet.create({
    container: {
        height: HEADER_HEIGHT,
        flexDirection: "row",
        borderBottomColor: colors.black,
        borderBottomWidth: 1
    },
    textContainer: {
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
        paddingHorizontal: 10
    },
    title: {
        color: colors.black,
        fontSize: 18,
        fontWeight: "bold"
        //textTransform: "uppercase"
    },
    closeContainer: {
        padding: 10,
        height: "100%",
        justifyContent: "center",
        alignItems: "center"
    }
});

function EditionsSecondaryModalHeader(props) {
    const { title, useCancelButton, useDoneButton, onClose, onSave } = props;

    let CancelComponent;
    let CloseComponent;
    if (useDoneButton) {
        if (useCancelButton) {
            CancelComponent = (
                <Css
                    classes={[
                        "opt-secondary-modal-header-icon-container",
                        "opt-secondary-modal-header-cancel-container"
                    ]}>
                    <TouchableOpacity onPress={onClose} style={styles.closeContainer}>
                        <Css classes={["opt-secondary-modal-header-cancel"]}>
                            <TaText>{LiveConfig.getLocale().strings("str_cancel")}</TaText>
                        </Css>
                    </TouchableOpacity>
                </Css>
            );
        }

        CloseComponent = (
            <Css classes={["opt-secondary-modal-header-icon-container", "opt-secondary-modal-header-close-container"]}>
                <TouchableOpacity
                    onPress={() => {
                        if (typeof onSave === "function") {
                            onSave();
                        }
                        onClose();
                    }}
                    style={styles.closeContainer}>
                    <Css classes={["opt-secondary-modal-header-done"]}>
                        <TaText style={{ fontWeight: "bold" }}>{LiveConfig.getLocale().strings("str_done")}</TaText>
                    </Css>
                </TouchableOpacity>
            </Css>
        );
    } else {
        CloseComponent = (
            <>
                {typeof onSave === "function" ? (
                    <Css
                        classes={[
                            "opt-secondary-modal-header-icon-container",
                            "opt-secondary-modal-header-save-container"
                        ]}>
                        <TouchableOpacity onPress={onSave} style={[styles.closeContainer, { width: HEADER_HEIGHT }]}>
                            <Css classes={["opt-secondary-modal-header-icon", "opt-secondary-modal-header-save"]}>
                                <TaImageIcon DefaultComponent={<IcContentSaveOutline />} />
                            </Css>
                        </TouchableOpacity>
                    </Css>
                ) : null}
                <Css
                    classes={[
                        "opt-secondary-modal-header-icon-container",
                        "opt-secondary-modal-header-close-container"
                    ]}>
                    <TouchableOpacity onPress={onClose} style={[styles.closeContainer, { width: HEADER_HEIGHT }]}>
                        <Css classes={["opt-secondary-modal-header-icon", "opt-secondary-modal-header-close"]}>
                            <TaImageIcon DefaultComponent={<IcClose />} />
                        </Css>
                    </TouchableOpacity>
                </Css>
            </>
        );
    }

    return (
        <Css classes={["opt-secondary-modal-header-container"]}>
            <View style={[styles.container]}>
                {CancelComponent}
                <Css classes={["opt-secondary-modal-header-text-container"]}>
                    <View style={styles.textContainer}>
                        <Css classes={["opt-secondary-modal-header-text"]}>
                            <TaText style={styles.title}>{title}</TaText>
                        </Css>
                    </View>
                </Css>
                {CloseComponent}
            </View>
        </Css>
    );
}

EditionsSecondaryModalHeader.propTypes = {
    title: PropTypes.string.isRequired,
    onClose: PropTypes.func.isRequired,
    onSave: PropTypes.func,
    useDoneButton: PropTypes.bool,
    useCancelButton: PropTypes.bool
};

export default EditionsSecondaryModalHeader;
