import React, { useCallback } from "react";
import PropTypes from "prop-types";
import CollapseLine from "../CollapseLine/collapse-line";
import Edition from "../../models/edition";
import EditionsSecondaryItemText from "./editions-secondary-item-text";
import { SearchTextContext, SelectedEditionsContext } from "../../data/user-config";

function hasEditionSelected(editions: Array<Edition> = [], selectedEditions: Array<String> = []) {
    for (let i = 0; i < editions.length; i++) {
        const edition = editions[i];
        if (selectedEditions.includes(edition.getName())) {
            return true;
        }
        const found = hasEditionSelected(edition.getGroup(), selectedEditions);
        if (found) {
            return true;
        }
    }
    return false;
}

function EditionsSecondaryModalItem(props) {
    const { edition, level, parentSelected, onPress } = props;

    const onBookmarkPress = useCallback(() => {
        if (typeof onPress === "function") {
            onPress(edition);
        }
    });

    return (
        <SelectedEditionsContext.Consumer>
            {(value: Array = []) => (
                <SearchTextContext.Consumer>
                    {(filteredEditions: Array) => {
                        const searchActive = filteredEditions && filteredEditions.includes(edition.getName());
                        if (!filteredEditions || searchActive) {
                            const lineCollapsed = searchActive
                                ? false
                                : !hasEditionSelected(edition.getGroup(), value) && level > 1;
                            return (
                                <CollapseLine
                                    key={`edition_${edition.getName()}`}
                                    line={edition}
                                    lineCollapsed={lineCollapsed}
                                    lineLevel={level + 1}
                                    lineToggle
                                    lineChildren={edition.getGroup()}
                                    renderLineLeft={(item: Edition, collapsed: Boolean) => (
                                        <EditionsSecondaryItemText
                                            onPress={onBookmarkPress}
                                            edition={item}
                                            selected={parentSelected || value.includes(item.getName())}
                                        />
                                    )}
                                    renderLineChild={(item: Edition, collapsed: Boolean, lineLevel: Number) => (
                                        <EditionsSecondaryModalItem
                                            key={`edition_${item.getName()}_${collapsed}`}
                                            edition={item}
                                            level={lineLevel}
                                            onPress={onPress}
                                            parentSelected={true}
                                        />
                                    )}
                                />
                            );
                        }

                        return null;
                    }}
                </SearchTextContext.Consumer>
            )}
        </SelectedEditionsContext.Consumer>
    );
}

EditionsSecondaryModalItem.propTypes = {
    edition: PropTypes.instanceOf(Edition).isRequired,
    onPress: PropTypes.func.isRequired,
    level: PropTypes.number
};

EditionsSecondaryModalItem.defaultProps = {
    level: 1
};

export default EditionsSecondaryModalItem;
