import React, { useCallback, useState } from "react";
import PropTypes from "prop-types";
import { View } from "react-native";
import IssueList from "../List/issue-list";
import Edition from "../../models/edition";
import EditionsHelper from "../../helpers/editions-helper";
import EditionsSecondaryEmpty from "./editions-secondary-empty";
import EditionsSecondaryModal from "./editions-secondary-modal";
import LiveConfig from "../../data/live-config";
import HeaderList from "../List/header-list";
import IcBookmarkPlus from "../Icon/ic-bookmark-plus";
import { colors } from "../../utils/colors";
import List from "../List/list";
import Issue from "../../models/issue";
import IssueCardItem from "../IssueItem/issue-card-item";
import { issueItemKey } from "../IssueItem/issue-item";

/**
 * display horizontal list of secondary editions
 * display secondary editions add button
 * @param {*} props
 * @returns
 */
function EditionsSecondary(props) {
    const { editions, mainEditionName, horizontal, forceShortcut, ...rest } = props;
    const [showModal, setShowModal] = useState(false);

    if (!editions || editions.length === 0) {
        return null;
    }

    const { selectedEditions } = LiveConfig.getSettings();
    //const nothingSelected = selectedEditions.length === 0;

    const show = useCallback(() => {
        setShowModal(true);
    });
    const hide = useCallback(() => {
        setShowModal(false);
    });

    let ListComponent = null;
    if (horizontal) {
        ListComponent = (
            <View>
                {selectedEditions.map((editionName: String, index) => {
                    if (editionName === mainEditionName) {
                        return null;
                    }
                    const edition: Edition = EditionsHelper.getEditionByName(editions, editionName);
                    return edition ? (
                        <IssueList
                            {...rest}
                            key={`selected_edition_${editionName}_${index}`}
                            title={edition.getLabel()}
                            issues={EditionsHelper.getIssuesFromSpecials([edition], mainEditionName, true)}
                            HeaderComponent={
                                <HeaderList
                                    title={edition.getLabel()}
                                    Icon={<IcBookmarkPlus width={20} height={20} />}
                                />
                            }
                            showTitle={forceShortcut || edition.isShortcut()}
                            horizontal
                        />
                    ) : null;
                })}
            </View>
        );
    } else {
        const { issueCallbacks } = props;
        //if vertical prepare a unique vertical list with all the secondary editions
        const secondaryEditions = selectedEditions.reduce((current, editionName: String) => {
            if (editionName === mainEditionName) {
                return null;
            }
            const edition: Edition = EditionsHelper.getEditionByName(editions, editionName);
            if (edition) {
                current.push(edition);
            }
            return current;
        }, []);

        const mIssue = new Issue();
        mIssue.setIssue("plus");
        mIssue.setEdition("plus");

        ListComponent = (
            <View>
                <List
                    {...rest}
                    key="selected_secondary_editions"
                    data={EditionsHelper.getIssuesFromSpecials(secondaryEditions, mainEditionName, true)}
                    horizontal={false}
                    numColumns={2}
                    keyExtractor={issueItemKey}
                    itemSize={{ height: 300 }}
                    containerStyle={{ maxWidth: 500, alignItems: "center" }}
                    renderItem={({ item, size, ...itemProps }) => (
                        <IssueCardItem
                            {...itemProps}
                            style={{ padding: 0, backgroundColor: colors.transparent }}
                            issueCallbacks={issueCallbacks}
                            showHighRes
                        />
                    )}
                />
            </View>
        );
    }

    return (
        <>
            {ListComponent}
            <EditionsSecondaryEmpty onPress={show} />
            <EditionsSecondaryModal editions={editions} onClose={hide} visible={showModal} />
        </>
    );
}

EditionsSecondary.propTypes = {
    mainEditionName: PropTypes.string,
    editions: PropTypes.arrayOf(PropTypes.instanceOf(Edition)),
    forceShortcut: PropTypes.bool,
    ...IssueList.propTypes
};

export default EditionsSecondary;
