import React, { useCallback, useState } from "react";
import PropTypes from "prop-types";
import { View } from "react-native";
import IssueList from "../List/issue-list";
import Edition from "../../models/edition";
import EditionsHelper from "../../helpers/editions-helper";
import EditionsSecondaryEmpty from "./editions-secondary-empty";
import EditionsSecondaryModal from "./editions-secondary-modal";
import LiveConfig from "../../data/live-config";
import List from "../List/list";
import Issue from "../../models/issue";
import { issueItemKey } from "../IssueItem/issue-item";
import TaText from "../Tecnavia/ta-text";
import { commonStyles, MAIN_VIEW_PADDING, MAX_SCREEN_WIDTH } from "../Css/common-styles";
import IssueCardItem from "../IssueItem/issue-card-item";
import Grid from "../Grid/grid";

/**
 * display horizontal list of secondary editions
 * display secondary editions add button
 * @param {*} props
 * @returns
 */
function EditionsSecondary(props) {
    const { editions, mainEditionName, horizontal, forceShortcut, issueSize, issueCallbacks, ...rest } = props;
    const [showModal, setShowModal] = useState(false);
    const [layout, setLayout] = useState();

    if (!editions || editions.length === 0) {
        return null;
    }

    const { selectedEditions } = LiveConfig.getSettings();

    const show = useCallback(() => {
        setShowModal(true);
    });

    const hide = useCallback(() => {
        setShowModal(false);
    });

    const onLayout = ({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    };

    let issues = [];
    if (selectedEditions) {
        //if vertical prepare a unique vertical list with all the secondary editions
        const secondaryEditions = selectedEditions.reduce((current, editionName: String) => {
            if (editionName === mainEditionName) {
                return null;
            }
            const edition: Edition = EditionsHelper.getEditionByName(editions, editionName);
            if (edition) {
                current.push(edition);
            }
            return current;
        }, []);

        issues = EditionsHelper.getIssuesFromSpecials(secondaryEditions, mainEditionName, true);
    }

    let ListComponent = null;
    if (layout) {
        const plusIssue = new Issue();
        plusIssue.setIssue("plus");
        plusIssue.setEdition("plus");

        const showPlusAtBottom = layout.width < 450;

        const data = issues;
        if (!showPlusAtBottom) {
            data.push(plusIssue);
        }

        const itemStyle = {};

        ListComponent = (
            <>
                <Grid
                    data={data}
                    baseItemSize={issueSize}
                    renderItem={(item) => {
                        if (item.getIssue() === "plus" && item.getEdition() === "plus") {
                            return <EditionsSecondaryEmpty onPress={show} style={itemStyle} />;
                        }
                        return (
                            <IssueCardItem
                                item={item}
                                style={[commonStyles.container, itemStyle]}
                                showHighRes
                                issueCallbacks={issueCallbacks}
                            />
                        );
                    }}
                />
                {showPlusAtBottom ? <EditionsSecondaryEmpty onPress={show} style={itemStyle} /> : null}
            </>
        );
    }

    return (
        <>
            <View onLayout={onLayout} style={{ width: "100%", maxWidth: MAX_SCREEN_WIDTH }}>
                <TaText style={{ fontSize: 20, marginHorizontal: MAIN_VIEW_PADDING / 5 }}>
                    {LiveConfig.getLocale().strings("str_modal_header_preferred_edition")}
                </TaText>
                {ListComponent}
            </View>
            <EditionsSecondaryModal editions={editions} onClose={hide} visible={showModal} />
        </>
    );
}

EditionsSecondary.defaultProps = {
    issueSize: {
        width: 150,
        height: 200
    }
};

EditionsSecondary.propTypes = {
    mainEditionName: PropTypes.string,
    editions: PropTypes.arrayOf(PropTypes.instanceOf(Edition)),
    forceShortcut: PropTypes.bool,
    issueSize: PropTypes.object,
    ...IssueList.propTypes
};

export default EditionsSecondary;
