import React from "react";
import { StyleSheet, View } from "react-native";
import PropTypes from "prop-types";

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "row",
        flexWrap: "wrap"
    }
});

function Grid(props) {
    const { data, style } = props;

    return (
        <View style={[styles.container, style]}>
            {data.map((otherIssue, index) => {
                const parentStyle = [];
                const style = [];
                if (numColumns > 1) {
                    const parentMargin = Math.max(
                        (referenceWidth - insertIssueWidth * numColumns) / (numColumns - 1) / 2,
                        0
                    );
                    //ensure a minimum margin between tiles
                    const margin = parentMargin > 0 ? 0 : 5;
                    if (index % numColumns === 0) {
                        parentStyle.push({ marginRight: parentMargin });
                        style.push({ marginRight: margin });
                    } else if ((index + 1) % numColumns === 0) {
                        parentStyle.push({ marginLeft: parentMargin });
                        style.push({ marginLeft: margin });
                    } else {
                        parentStyle.push({ marginHorizontal: parentMargin });
                        style.push({ marginHorizontal: margin });
                    }
                }
                return (
                    <View style={[{ width: insertIssueWidth, height: insertIssueHeight }, parentStyle]}>
                        <IssueCardItem
                            item={otherIssue}
                            style={[{ marginHorizontal: 0 }, style]}
                            imageStyle={styles.otherIssueImage}
                            imageParentStyle={styles.otherIssueImageContainer}
                            showHighRes
                            showTitle
                            issueCallbacks={issueCallbacks}
                        />
                    </View>
                );
            })}
        </View>
    );
}
Grid.propTypes = {
    renderItem: PropTypes.func,
    renderVerticalItem: PropTypes.func,
    renderHorizontalItem: PropTypes.func,
    keyExtractor: PropTypes.func.isRequired,
    data: PropTypes.array.isRequired,
    cssListClasses: PropTypes.array,
    listContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    horizontal: PropTypes.bool,
    removeClippedSubviews: PropTypes.bool,
    initialNumToRender: PropTypes.number,
    itemSize: PropTypes.object
};

Grid.defaultProps = {
    horizontal: true,
    initialNumToRender: 5,
    removeClippedSubviews: true,
    cssListClasses: []
};

export default Grid;
