import React, { useCallback, useState } from "react";
import { StyleSheet, View } from "react-native";
import PropTypes from "prop-types";

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "row",
        flexWrap: "wrap"
    }
});

function Grid(props) {
    const { data, style, renderItem, baseItemSize } = props;

    const [layout, setLayout] = useState();
    const onLayout = useCallback(({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    });

    let GridElements = null;
    if (layout) {
        const { width } = layout;
        let { width: baseItemWidth, height: baseItemHeight } = baseItemSize;
        const aspectRatio = baseItemHeight / baseItemWidth;
        let numColumns = Math.floor(width / baseItemWidth);

        const availableRightSpace = width - baseItemWidth * numColumns;
        if (availableRightSpace < baseItemWidth * 0.5) {
            baseItemWidth += Math.floor(availableRightSpace / numColumns);
            baseItemHeight = baseItemWidth / aspectRatio;
        } else if (availableRightSpace > insertIssueWidth * 0.75) {
            numColumns += 1;
            insertIssueWidth = Math.floor(width / numColumns);
            insertIssueHeight = insertIssueWidth / aspectRatio;
        }

        GridElements = data.map((item, index) => {
            const parentStyle = [];
            const itemStyle = [];
            if (numColumns > 1) {
                const parentMargin = Math.max((width - baseItemWidth * numColumns) / (numColumns - 1) / 2, 0);
                //ensure a minimum margin between tiles
                const margin = parentMargin > 0 ? 0 : 5;
                if (index % numColumns === 0) {
                    parentStyle.push({ marginRight: parentMargin });
                    itemStyle.push({ marginRight: margin });
                } else if ((index + 1) % numColumns === 0) {
                    parentStyle.push({ marginLeft: parentMargin });
                    itemStyle.push({ marginLeft: margin });
                } else {
                    parentStyle.push({ marginHorizontal: parentMargin });
                    itemStyle.push({ marginHorizontal: margin });
                }
            }
            return (
                <View style={[{ width: insertIssueWidth, height: insertIssueHeight }, parentStyle]}>
                    {renderItem({ item, itemStyle })}
                </View>
            );
        });
    }

    return (
        <View style={[styles.container, style]} onLayout={onLayout}>
            {GridElements}
        </View>
    );
}
Grid.propTypes = {
    data: PropTypes.array.isRequired,
    renderItem: PropTypes.func.isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    baseItemSize: PropTypes.object
};

Grid.defaultProps = {};

export default Grid;
