import React, { useCallback, useState } from "react";
import { StyleSheet, View } from "react-native";
import PropTypes from "prop-types";

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "row",
        flexWrap: "wrap"
    }
});

function Grid(props) {
    const { data, style, renderItem, baseItemSize, numberOfColumns } = props;

    const [layout, setLayout] = useState();
    const onLayout = useCallback(({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    });

    let containerStyle;
    let GridElements = null;
    if (layout) {
        const { width } = layout;

        let numColumns = 1;
        let itemWidth;
        let itemHeight;
        if (baseItemSize) {
            ({ width: itemWidth, height: itemHeight } = baseItemSize);
            const aspectRatio = itemHeight / itemWidth;
            numColumns = Math.floor(width / itemWidth);

            const availableRightSpace = width - itemWidth * numColumns;
            if (availableRightSpace < itemWidth * 0.5) {
                itemWidth += Math.floor(availableRightSpace / numColumns);
                itemHeight = itemWidth / aspectRatio;
            } else if (availableRightSpace > itemWidth * 0.75) {
                numColumns += 1;
                itemWidth = Math.floor(width / numColumns);
                itemHeight = itemWidth / aspectRatio;
            }
        } else if (numberOfColumns) {
            numColumns = numberOfColumns;
            itemWidth = width / numberOfColumns;
        }

        if (numColumns > 1) {
            //check the availablespace to determine hoe to place the elements
            if (width - itemWidth * numColumns < itemWidth) {
                containerStyle = { justifyContents: "space-between" };
            }
        }

        GridElements = data.map((item, index) => {
            const parentStyle = [];
            const itemStyle = [];
            if (numColumns > 1) {
                /* const parentMargin = Math.max((width - itemWidth * numColumns) / (numColumns - 1) / 2, 0);
                //ensure a minimum margin between tiles
                const margin = parentMargin > 0 ? 0 : 5;
                if (index % numColumns === 0) {
                    parentStyle.push({ marginRight: parentMargin });
                    itemStyle.push({ marginRight: margin });
                } else if ((index + 1) % numColumns === 0) {
                    parentStyle.push({ marginLeft: parentMargin });
                    itemStyle.push({ marginLeft: margin });
                } else {
                    parentStyle.push({ marginHorizontal: parentMargin });
                    itemStyle.push({ marginHorizontal: margin });
                }*/
            }
            return (
                <View style={[{ width: itemWidth, height: itemHeight }, parentStyle]}>
                    {renderItem({ item, itemStyle })}
                </View>
            );
        });
    }

    return (
        <View style={[styles.container, containerStyle, style]} onLayout={onLayout}>
            {GridElements}
        </View>
    );
}
Grid.propTypes = {
    data: PropTypes.array.isRequired,
    renderItem: PropTypes.func.isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    baseItemSize: PropTypes.object,
    numberOfColumns: PropTypes.number
};

Grid.defaultProps = {};

export default Grid;
