import React from "react";
import PropTypes from "prop-types";
import { View, StyleSheet } from "react-native";
import { colors } from "../../utils/colors";
import HamburgerButton from "./hamburger-button";
import Logo from "./logo";
import CloseButton from "./close-button";
import { commonStyles, HEADER_HEIGHT } from "../Css/common-styles";
import PlaceHolderButton from "./placeholder-button";
import { Css } from "../Css/css";

const styles = StyleSheet.create({
    header: {
        width: "100%",
        flexDirection: "row",
        alignItems: "center",
        justifyContent: "space-between",
        paddingVertical: 10,
        height: HEADER_HEIGHT,
        backgroundColor: colors.white
    }
});

function MainHeader(props) {
    const {
        backgroundColor,
        foregroundColor,
        style,
        hideHamburger,
        onClose,
        LogoComponent,
        onLogoPress,
        showCloseButton
    } = props;

    return (
        <Css classes={["opt-header"]}>
            <View
                style={[
                    styles.header,
                    commonStyles.shadow,
                    {
                        backgroundColor
                    },
                    style
                ]}>
                {hideHamburger ? (
                    <PlaceHolderButton backgroundColor={backgroundColor} />
                ) : (
                    <HamburgerButton backgroundColor={backgroundColor} iconColor={foregroundColor} />
                )}
                <Logo Component={LogoComponent} onLogoPress={onLogoPress} backgroundColor={backgroundColor} />
                {showCloseButton ? (
                    <CloseButton onClose={onClose} backgroundColor={backgroundColor} iconColor={foregroundColor} />
                ) : null}
            </View>
        </Css>
    );
}

MainHeader.propTypes = {
    backgroundColor: PropTypes.string,
    foregroundColor: PropTypes.string,
    onClose: PropTypes.func,
    hideHamburger: PropTypes.bool,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    LogoComponent: PropTypes.oneOfType([PropTypes.func, PropTypes.node, PropTypes.string]),
    onLogoPress: PropTypes.func,
    showCloseButton: PropTypes.bool
};

MainHeader.defaultProps = {
    backgroundColor: colors.white,
    foregroundColor: colors.black,
    hideHamburger: false,
    showCloseButton: true
};

export default MainHeader;
