import React from "react";
import PropTypes from "prop-types";
import { View, StyleSheet } from "react-native";
import Issue from "../../models/issue";
import { getGraphUrl, getLowUrl, getTextUrl } from "../../utils/api";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import TaImageIcon from "../Tecnavia/ta-image-icon";

const styles = StyleSheet.create({
    imageText: {
        shadowOffset: { wisth: 0, height: 0 }
    }
});

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function IssueImage(props) {
    const { item, style, showHighRes }: { item: Issue } = props;

    if (!item) {
        return null;
    }

    const imageProps = {
        resizeMode: "contain"
    };

    return (
        <Css classes={["opt-issue-image-container"]}>
            <View style={commonStyles.container}>
                {!showHighRes ? (
                    <Css classes={["opt-issue-image", "opt-issue-image-low"]}>
                        <TaImageIcon
                            style={[commonStyles.full, style]}
                            source={{
                                uri: getLowUrl(item)
                            }}
                            {...imageProps}
                        />
                    </Css>
                ) : (
                    <>
                        <Css classes={["opt-issue-image", "opt-issue-image-graph"]}>
                            <TaImageIcon
                                style={[commonStyles.full, style]}
                                source={{ uri: getGraphUrl(item) }}
                                {...imageProps}
                            />
                        </Css>
                        <Css classes={["opt-issue-image", "opt-issue-image-text"]}>
                            <TaImageIcon
                                style={[commonStyles.full, styles.imageText, style]}
                                source={{ uri: getTextUrl(item) }}
                                {...imageProps}
                            />
                        </Css>
                    </>
                )}
            </View>
        </Css>
    );
}

IssueImage.propTypes = {
    item: PropTypes.instanceOf(Issue).isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    showHighRes: PropTypes.bool
};

IssueImage.defaultProps = {};

export default IssueImage;
