import React, { useCallback } from "react";
import PropTypes from "prop-types";
import { View, StyleSheet, TouchableOpacity } from "react-native";
import Issue from "../../models/issue";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import TaText from "../Tecnavia/ta-text";
import IssueImage from "../IssueImage/issue-image";
import { isIOS } from "../../utils/platform";

const styles = StyleSheet.create({
    imageText: {},
    footer: {
        height: 20,
        justifyContent: "center"
    },
    footerText: {
        textAlign: "center"
    }
});

function issueItemKey(item: Issue, index) {
    return `${item.getIssue()}_${index}`;
}

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function IssueItem(props) {
    const {
        item,
        style,
        imageContainerStyle,
        imageStyle,
        footerStyle,
        footerTextStyle,
        issueCallbacks,
        showHighRes,
        showImageShadow,
        showTitle,
        hideTitle
    }: { item: Issue } = props;
    const { onIssuePress } = issueCallbacks;
    const onPress = useCallback(() => {
        if (typeof onIssuePress === "function") {
            onIssuePress(item);
        }
    }, []);

    if (!item) {
        return null;
    }

    let containerStyle = {};
    const issueImageStyle = [imageStyle];
    if (showImageShadow) {
        if (isIOS()) {
            containerStyle = commonStyles.shadow;
        } else {
            issueImageStyle.push(commonStyles.shadow);
        }
    }

    return (
        <TouchableOpacity style={style} onPress={onPress} collapsable={false}>
            <View style={imageContainerStyle}>
                <IssueImage
                    showHighRes={showHighRes}
                    item={item}
                    style={issueImageStyle}
                    containerStyle={containerStyle}
                />
            </View>
            {!hideTitle ? (
                <Css classes={["opt-issue-footer"]}>
                    <View style={[styles.footer, footerStyle]}>
                        <Css classes={["opt-issue-footer-text"]}>
                            <TaText style={[styles.footerText, footerTextStyle]}>
                                {showTitle ? item.getEdition() : item.getDateLabel()}
                            </TaText>
                        </Css>
                    </View>
                </Css>
            ) : null}
        </TouchableOpacity>
    );
}

IssueItem.propTypes = {
    item: PropTypes.instanceOf(Issue).isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    footerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    footerTextStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    issueCallbacks: PropTypes.shape({
        onIssuePress: PropTypes.func
    }),
    showTitle: PropTypes.bool,
    hideTitle: PropTypes.bool,
    showHighRes: PropTypes.bool,
    showImageShadow: PropTypes.bool
};

IssueItem.defaultProps = {
    style: commonStyles.container,
    issueCallbacks: {},
    showTitle: false,
    showHighRes: false,
    hideTitle: false
};

export { issueItemKey };
export default IssueItem;
