import React, { useCallback } from "react";
import PropTypes from "prop-types";
import { View, StyleSheet, TouchableOpacity } from "react-native";
import Issue from "../../models/issue";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import TaText from "../Tecnavia/ta-text";
import IssueImage from "../IssueImage/issue-image";
import CssHelper from "../Css/css-methods";

const styles = StyleSheet.create({
    imageText: {},
    imageParent: {
        flex: 1
    },
    footer: {
        height: 20,
        justifyContent: "center"
    },
    footerText: {
        textAlign: "center"
    }
});

function issueItemKey(item: Issue, index) {
    return `${item.getIssue()}_${index}`;
}

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function IssueItem(props) {
    const {
        item,
        cssPrefix,
        style,
        imageParentStyle,
        imageStyle,
        imageGraphStyle,
        imageTextStyle,
        footerParentStyle,
        footerStyle,
        issueCallbacks,
        showHighRes,
        showTitle,
        hideTitle
    }: { item: Issue } = props;
    const { onIssuePress } = issueCallbacks;
    const onPress = useCallback(() => {
        if (typeof onIssuePress === "function") {
            onIssuePress(item);
        }
    }, []);

    if (!item) {
        return null;
    }

    return (
        <Css classes={["opt-issue-item-container"]} cssKey={cssPrefix}>
            <TouchableOpacity style={style} onPress={onPress} collapsable={false}>
                <Css classes={["opt-issue-item-image-container"]} cssKey={cssPrefix}>
                    <View style={[styles.imageParent, imageParentStyle]}>
                        <Css classes={["opt-issue-item-image"]} cssKey={cssPrefix}></Css>
                    </View>
                </Css>
                {!hideTitle ? (
                    <Css classes={["opt-issue-item-footer-container"]} cssKey={cssPrefix}>
                        <View style={[styles.footer, footerParentStyle]}>
                            <Css classes={["opt-issue-item-footer-text"]} cssKey={cssPrefix}>
                                <TaText style={[styles.footerText, footerStyle]}>
                                    {showTitle ? item.getEdition() : item.getDateLabel()}
                                </TaText>
                            </Css>
                        </View>
                    </Css>
                ) : null}
            </TouchableOpacity>
        </Css>
    );
}

IssueItem.propTypes = {
    item: PropTypes.instanceOf(Issue).isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageParentStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageGraphStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageTextStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    footerParentStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    footerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    issueCallbacks: PropTypes.shape({
        onIssuePress: PropTypes.func
    }),
    showTitle: PropTypes.bool,
    hideTitle: PropTypes.bool,
    showHighRes: PropTypes.bool,
    cssPrefix: PropTypes.string
};

IssueItem.defaultProps = {
    style: commonStyles.container,
    issueCallbacks: {},
    cssPrefix: "",
    showTitle: false,
    showHighRes: false,
    hideTitle: false
};

export { issueItemKey };
export default IssueItem;
