import React from "react";
import PropTypes from "prop-types";
import Issue from "../../models/issue";
import IssueItem, { issueItemKey } from "../IssueItem/issue-item";
import List from "./list";
import IssueCardItem from "../IssueItem/issue-card-item";
import IssueFlatItem from "../IssueItem/issue-flat-item";
import LayoutList from "./layout-list";

/**
 * component that choose wich kind of list render
 * evaluate also item size by checking first issue aspect ratio and parent constraint
 * @param {*} props
 * @returns
 */
function IssueList(props) {
    const { horizontal, issues, issueCallbacks, showTitle, ...rest } = props;
    return (
        <LayoutList
            aspectRatioItem={issues[0]}
            horizontal={horizontal}
            data={issues}
            keyExtractor={issueItemKey}
            renderVerticalItem={(itemProps) => (
                <IssueCardItem {...itemProps} showTitle={showTitle} issueCallbacks={issueCallbacks} />
            )}
            renderHorizontalItem={(itemProps) => (
                <IssueFlatItem {...itemProps} showTitle={showTitle} issueCallbacks={issueCallbacks} />
            )}
            {...rest}
        />
    );
}

IssueList.propTypes = {
    horizontal: PropTypes.bool,
    removeClippedSubviews: PropTypes.bool,
    initialNumToRender: PropTypes.number,
    showTitle: PropTypes.bool,
    issues: PropTypes.arrayOf(PropTypes.instanceOf(Issue)),
    issueCallbacks: IssueItem.propTypes.issueCallbacks,
    useLayoutList: PropTypes.bool
};

IssueList.defaultProps = {
    horizontal: true,
    initialNumToRender: 5,
    removeClippedSubviews: true,
    showTitle: false,
    useLayoutList: true
};

export default IssueList;
