import React from "react";
import { StyleSheet, View } from "react-native";
import PropTypes from "prop-types";
import HorizontalList from "./horizontal-list";
import VerticalList from "./vertical-list";
import CssHelper from "../Css/css-methods";
import { commonStyles } from "../Css/common-styles";

const styles = StyleSheet.create({
    container: {
        flex: 1
    }
});

function BaseList(props) {
    const { horizontal, renderItem, renderVerticalItem, renderHorizontalItem, ...rest } = props;

    const ListComponent = horizontal ? HorizontalList : VerticalList;
    const listConstraintRender = horizontal ? renderHorizontalItem : renderVerticalItem;
    return (
        <ListComponent
            {...rest}
            renderItem={(itemProps) => {
                const { style } = itemProps;
                if (typeof listConstraintRender === "function") {
                    return <View style={style}>{listConstraintRender(itemProps)}</View>;
                }
                if (typeof renderItem === "function") {
                    return <View style={style}>{renderItem(itemProps)}</View>;
                }
                return null;
            }}
        />
    );
}

/**
 * component that choose wich kind of list render
 * evaluate also item size by checking first issue aspect ratio and parent constraint
 * @param {*} props
 * @returns
 */
function List(props) {
    const { cssListClasses, listContainerStyle, ...rest } = props;

    const cssListContainer = CssHelper.flatten(
        [styles.container, commonStyles.margin, listContainerStyle],
        ["opt-list-container", ...cssListClasses]
    );

    return (
        <View style={cssListContainer}>
            <BaseList {...rest} />
        </View>
    );
}

List.propTypes = {
    renderItem: PropTypes.func,
    renderVerticalItem: PropTypes.func,
    renderHorizontalItem: PropTypes.func,
    keyExtractor: PropTypes.func.isRequired,
    data: PropTypes.array.isRequired,
    cssListClasses: PropTypes.array,
    listContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    horizontal: PropTypes.bool,
    removeClippedSubviews: PropTypes.bool,
    initialNumToRender: PropTypes.number,
    itemSize: PropTypes.object
};

List.defaultProps = {
    horizontal: true,
    initialNumToRender: 5,
    removeClippedSubviews: true,
    cssListClasses: []
};

export default List;
export { BaseList };
