import React, { useState } from "react";
import PropTypes from "prop-types";
import { FlatList, Platform, StyleSheet, View } from "react-native";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import CssHelper from "../Css/css-methods";

const styles = StyleSheet.create({
    container: {},
    list: {
        ...Platform.select({
            web: {
                overflow: "auto"
            }
        })
    }
});

/**
 * render issue list in vertical mode,
 * evaluate also the number of columns
 * @param {*} props
 * @returns
 */
function VerticalList(props) {
    const { itemSize, containerStyle, contentContainerStyle, ...rest } = props;

    const [layout, setLayout] = useState();

    const onLayout = ({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    };

    let { numColumns } = rest;
    if (!numColumns) {
        numColumns = 1;
        if (layout) {
            numColumns = Math.floor(layout.width / itemSize.width) || 1;
        }
        rest.numColumns = numColumns;
    }

    return (
        <Css classes={["opt-issues-container", "opt-issues-container-vertical"]}>
            <View
                style={[commonStyles.container, styles.container, containerStyle]}
                onLayout={onLayout}
                collapsable={false}>
                {layout ? (
                    <Css classes={["opt-issues-list", "opt-issues-list-vertical"]}>
                        <FlatList
                            key={`edition_list_cols_${numColumns}`}
                            contentContainerStyle={CssHelper.flatten(
                                [styles.list],
                                ["opt-issues-list-container", "opt-issues-list-container-vertical"],
                                contentContainerStyle
                            )}
                            {...rest}
                        />
                    </Css>
                ) : null}
            </View>
        </Css>
    );
}

VerticalList.propTypes = {
    data: PropTypes.array,
    itemSize: PropTypes.shape({
        width: PropTypes.number,
        height: PropTypes.number
    }),
    numColumns: PropTypes.number,
    renderItem: PropTypes.func,
    keyExtractor: PropTypes.func,
    containerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    contentContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array])
};

export default VerticalList;
