import React, { useState } from "react";
import PropTypes from "prop-types";
import { FlatList, Platform, StyleSheet, View } from "react-native";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import CssHelper from "../Css/css-methods";

const styles = StyleSheet.create({
    container: {},
    list: {
        ...Platform.select({
            web: {
                overflow: "auto"
            }
        })
    }
});

/**
 * render issue list in vertical mode,
 * evaluate also the number of columns
 * @param {*} props
 * @returns
 */
function VerticalList(props) {
    const { itemSize, containerStyle, contentContainerStyle, renderItem, gridMode, data, ...rest } = props;

    const [layout, setLayout] = useState();

    const onLayout = ({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    };
    let { numColumns } = rest;
    if (!numColumns) {
        numColumns = 1;
        if (layout) {
            numColumns = Math.floor(layout.width / itemSize.width) || 1;
        }
        rest.numColumns = numColumns;
    }
    if (!itemSize.width && layout) {
        itemSize.width = Math.floor(layout.width / numColumns);
    }

    return (
        <Css classes={["opt-issues-container", "opt-issues-container-vertical"]}>
            <View
                style={[commonStyles.container, styles.container, containerStyle]}
                onLayout={onLayout}
                collapsable={false}>
                {layout ? (
                    <Css classes={["opt-issues-list", "opt-issues-list-vertical"]}>
                        <FlatList
                            key={`edition_list_cols_${numColumns}`}
                            data={data}
                            contentContainerStyle={CssHelper.flatten(
                                [styles.list, contentContainerStyle],
                                ["opt-issues-list-container", "opt-issues-list-container-vertical"]
                            )}
                            style={{ overflow: "visible" }}
                            renderItem={({ item, index }) => {
                                const style = [itemSize];
                                //if gridMode compute the margin of the item automatically
                                if (gridMode) {
                                    const margin = (layout.width - itemSize.width * numColumns) / numColumns - 1;
                                    if (index % numColumns === 0) {
                                        style.push({ marginRight: margin });
                                    } else if ((index + 1) % numColumns === 0) {
                                        style.push({ marginLeft: margin });
                                    } else {
                                        style.push({ marginHorizontal: margin });
                                    }
                                }
                                const itemProps = { item, index, style };
                                return renderItem(itemProps);
                            }}
                            numColumns={numColumns}
                            {...rest}
                        />
                    </Css>
                ) : null}
            </View>
        </Css>
    );
}

VerticalList.propTypes = {
    data: PropTypes.array,
    itemSize: PropTypes.shape({
        width: PropTypes.number,
        height: PropTypes.number
    }),
    numColumns: PropTypes.number,
    renderItem: PropTypes.func,
    keyExtractor: PropTypes.func,
    containerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    contentContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array])
};

export default VerticalList;
