import React, { Component } from "react";
import PropTypes from "prop-types";
import { Keyboard, View } from "react-native";
import { colors } from "../../utils/colors";
import { Css } from "../Css/css";
import CssStyle from "../Css/css-styles";

export class SearchInput extends Component {
    static propTypes = {
        afterFocus: PropTypes.func,
        afterSearch: PropTypes.func,
        autoCapitalize: PropTypes.string,
        autoFocus: PropTypes.bool,
        beforeFocus: PropTypes.func,
        beforeSearch: PropTypes.func,
        blurOnSubmit: PropTypes.bool,
        editable: PropTypes.bool,
        keyboardShouldPersist: PropTypes.bool,
        keyboardType: PropTypes.string,
        onBlur: PropTypes.func,
        onChangeText: PropTypes.func,
        onFocus: PropTypes.func,
        onSearch: PropTypes.func,
        placeholder: PropTypes.string,
        mainColor: PropTypes.string,
        textBackgroundColor: PropTypes.string,
        textColor: PropTypes.string,
        borderRadius: PropTypes.number,
        style: PropTypes.any
    };

    static defaultProps = {
        editable: true,
        blurOnSubmit: false,
        keyboardShouldPersist: false,
        mainColor: colors.black,
        textBackgroundColor: colors.white,
        textColor: colors.black,
        borderRadius: 0,
        autoFocus: false
    };

    constructor(props) {
        super(props);

        const { placeholder } = this.props;
        /**
         * local variables
         */
        this.placeholder = placeholder || "Search";

        /**
         * functions
         */
        this.onFocus = this._onFocus.bind(this);
        this.onSearch = this._onSearch.bind(this);
        this.onChangeText = this._onChangeText.bind(this);

        this.state = {
            keyword: ""
        };
    }

    /**
     * onSearch
     * async await
     */
    async _onSearch() {
        const { beforeSearch, keyboardShouldPersist, onSearch, afterSearch } = this.props;
        const { keyword } = this.state;
        if (beforeSearch) {
            await beforeSearch(keyword);
        }
        if (keyboardShouldPersist === false) {
            await Keyboard.dismiss();
        }
        if (onSearch) {
            await onSearch(keyword);
        }
        if (afterSearch) {
            await afterSearch(keyword);
        }
    }

    /**
     * onChangeText
     * async await
     */
    async _onChangeText(text) {
        const { onChangeText } = this.props;
        const { keyword } = this.state;
        await this.setState({ keyword: text });
        if (onChangeText) {
            await onChangeText(keyword);
        }
    }

    /**
     * onFocus
     * async await
     */
    async _onFocus() {
        const { beforeFocus, onFocus, afterFocus } = this.props;
        const { keyword } = this.state;
        if (beforeFocus) {
            await beforeFocus();
        }

        if (this.inputKeyword && !this.inputKeyword.isFocused()) {
            await this.inputKeyword.focus();
        }
        if (onFocus) {
            await onFocus(keyword);
        }
        if (afterFocus) {
            await afterFocus();
        }
    }

    render() {
        const {
            editable,
            onBlur,
            blurOnSubmit,
            keyboardType,
            autoCapitalize,
            autoFocus,
            mainColor,
            textBackgroundColor,
            textColor,
            borderRadius,
            style
        } = this.props;
        const { keyword } = this.state;

        const searchTextStyle = Css.getStyleObjByCssClasses(["search-input"]);
        const borderColor = CssStyle.getAttributeFromStyle("borderColor", [style, searchTextStyle], mainColor);
        const color = CssStyle.getAttributeFromStyle("color", [style, searchTextStyle], textColor);
        const backgroundColor = CssStyle.getAttributeFromStyle(
            "backgroundColor",
            [style, searchTextStyle],
            textBackgroundColor
        );
        return (
            <Css classes={["search-container"]}>
                <View style={[styles.container, { backgroundColor: borderColor }]}>
                    <FontTextInput
                        innerRef={(inputKeyword) => {
                            this.inputKeyword = inputKeyword;
                        }}
                        style={[
                            styles.input,
                            searchTextStyle,
                            style,
                            {
                                borderColor,
                                backgroundColor,
                                borderWidth: 1,
                                borderRadius,
                                color
                            }
                        ]}
                        editable={editable}
                        value={keyword}
                        onChangeText={this.onChangeText}
                        placeholder={this.placeholder}
                        placeholderTextColor={color}
                        onSubmitEditing={this.onSearch}
                        autoCorrect={false}
                        blurOnSubmit={blurOnSubmit}
                        returnKeyType="search"
                        keyboardType={keyboardType || "default"}
                        autoCapitalize={autoCapitalize}
                        onBlur={onBlur}
                        onFocus={this.onFocus}
                        underlineColorAndroid="transparent"
                        autoFocus={autoFocus}
                    />
                </View>
            </Css>
        );
    }
}
