import React from "react";
import PropTypes from "prop-types";
import { createMaterialTopTabNavigator } from "@react-navigation/material-top-tabs";
import RouteEditionsDate from "../../models/route-editions-date";
import RouteEdition from "../../models/route-edition";
import EditionsNested from "../EditionsNested/editions-nested";
import ColorUtils, { colors } from "../../utils/colors";
import CssHelper from "../Css/css-methods";
import LiveConfig from "../../data/live-config";
import { commonStyles } from "../Css/common-styles";
import IssueItem from "../IssueItem/issue-item";
import EditionDayContainer from "../EditionDayPage/edition-day-container";
import TaText from "../Tecnavia/ta-text";
import { fontScale } from "../../utils/platform";
import RouteUrl from "../../models/route-url";
import UrlPage from "../UrlPage/url-page";

const Tab = createMaterialTopTabNavigator();

function getTabWidth() {
    const style = CssHelper.getStyleObjByCssClasses(["opt-tab-item"]);
    return style.width !== undefined ? style.width : 140 * fontScale();
}

function getTabIndicatorHeight() {
    const style = CssHelper.getStyleObjByCssClasses(["opt-tab-indicator"]);
    return style.heigth !== undefined ? style.heigth : 2;
}

function renderTabScreens({ routes, props = {} }) {
    const { textColor, ...rest } = props;
    const screens = [];
    routes.forEach((route) => {
        const ScreenProps = {
            name: route.getText(),
            key: route.getRoute(),
            options: {
                tabBarLabel: (label) => (
                    <TaText
                        numberOfLines={1}
                        style={{ color: textColor, maxWidth: getTabWidth(), paddingHorizontal: 10 }}>
                        {route.getText().toUpperCase()}
                    </TaText>
                )
            }
        };
        let Component = null;
        if (route instanceof RouteEditionsDate) {
            Component = (
                <Tab.Screen {...ScreenProps}>
                    {(navProps) => <EditionDayContainer main={route} {...rest} {...navProps} />}
                </Tab.Screen>
            );
        } else if (route instanceof RouteEdition) {
            Component = (
                <Tab.Screen {...ScreenProps}>
                    {(navProps) => <EditionsNested main={route.getEdition()} {...rest} {...navProps} />}
                </Tab.Screen>
            );
        } else if (route instanceof RouteUrl) {
            Component = (
                <Tab.Screen {...ScreenProps}>
                    {(navProps) => <UrlPage url={route.getUrl()} {...props} {...navProps} />}
                </Tab.Screen>
            );
        }

        if (Component) {
            screens.push(Component);
        }
    });
    return screens;
}

function TabNavigator(props) {
    const { routes, specials, issueCallbacks } = props;

    const tabStyle = CssHelper.getStyleObjByCssClasses(["opt-tab"]);
    const tabIndicatorStyle = CssHelper.getStyleObjByCssClasses(["opt-tab-indicator"]);
    const indicatorHeight = getTabIndicatorHeight();

    const tabBarStyle = { backgroundColor: LiveConfig.getSupportColor(), ...tabStyle, ...commonStyles.darkShadow };
    const { backgroundColor: tabBackgroundColor } = tabBarStyle;
    const textColor = ColorUtils.determineTextColor(tabBackgroundColor);

    return (
        <Tab.Navigator
            screenOptions={{
                tabBarItemStyle: {
                    width: getTabWidth(),
                    padding: 0,
                    paddingBottom: indicatorHeight,
                    margin: 0,
                    backgroundColor: colors.transparent
                },
                tabBarScrollEnabled: true,
                tabBarStyle,
                tabBarIndicatorStyle: {
                    backgroundColor: textColor,
                    height: indicatorHeight,
                    ...tabIndicatorStyle
                },
                lazy: true,
                lazyPreloadDistance: 1
            }}
            backBehavior="initialRoute">
            {renderTabScreens({ routes, props: { specials, issueCallbacks, textColor } })}
        </Tab.Navigator>
    );
}

TabNavigator.propTypes = {
    routes: PropTypes.array,
    specials: PropTypes.array,
    issueCallbacks: IssueItem.propTypes.issueCallbacks
};
export default TabNavigator;
