import React from "react";
import { Animated, Image, ImageProps, Platform } from "react-native";
import FastImage from "react-native-fast-image";
import PropTypes from "prop-types";
import CssStyle from "../Css/css-styles";
import TaSvg from "../Icon/svg";

/**
 * @param {*} props
 * @returns  default FastImage component
 */
function FSImage(props) {
    const { source, error, onError, ...rest } = props;
    if (error) {
        return null;
    }
    //fix cache
    if (source && source.cache === "reload") {
        source.cache = "web";
    }
    return (
        <FastImage
            onError={({ nativeEvent }) => {
                console.debug(nativeEvent);
                if (typeof onError === "function") {
                    onError();
                }
            }}
            source={source}
            {...rest}
        />
    );
}

function mapPropsOnComponent(props) {
    const { style, imageStyle, source, tintColor, ...rest } = props;
    const paths = CssStyle.getAttributeFromStyle("paths", style, []);
    const src = CssStyle.getAttributeFromStyle("src", style, "");

    const newProps = {
        Component: null,
        ...rest
    };
    const useSvg = paths && paths.length;
    const srcStyleIsValid = src && src.length;
    const srcPropIsValid = source || false;
    if (useSvg) {
        newProps.Component = TaSvg;
        newProps.style = style;
    } else if (srcPropIsValid || srcStyleIsValid) {
        newProps.Component = Platform.OS === "ios" ? FSImage : Image;
        newProps.style = CssStyle.deleteKeysFromStyle([imageStyle, style], ["color"]);
        newProps.source = source || src;
        newProps.tintColor = tintColor;
    }
    return newProps;
}

class TaImageIcon extends React.Component {
    render() {
        const { Component, DefaultComponent, ...rest } = mapPropsOnComponent(this.props);
        if (Component) {
            return <Component {...rest} />;
        }
        return DefaultComponent;
    }
}

TaImageIcon.propTypes = {
    style: PropTypes.any,
    imageStyle: PropTypes.any,
    iconStyle: PropTypes.any,
    size: PropTypes.number,
    tintColor: PropTypes.string,
    DefaultComponent: PropTypes.node,
    ...ImageProps
};

TaImageIcon.defaultProps = {
    DefaultComponent: null
};

const TaAnimatedImageIcon = Animated.createAnimatedComponent(TaImageIcon);

export { TaAnimatedImageIcon };
export default TaImageIcon;
