import React, { useCallback, useEffect, useRef } from "react";
import RNWebView, { WebViewProps } from "react-native-webview";
import Logger from "../../utils/log";
import { segmentURL } from "../../utils/strings";
import { EventRegister } from "../../events/manager";
import Events from "../../events/events";
import Message from "../../models/message";
import LiveConfig from "../../data/live-config";

function TaWebView(props) {
    const ref = useRef(null);

    const jsInjection = ({ js } = {}) => {
        if (ref && ref.current && js) {
            ref.current.injectJavaScript(/* javascript */ `
                try{
                    ${js}
                } catch(e){
                    console.log(e.message);
                }`);
        }
    };

    const shouldStartLoad = useCallback(({ url, navigationType }) => {
        if (url.startsWith("local://")) {
            const uri = segmentURL(url);
            Logger.debug(`domain: ${uri.getDomain()}`);
            EventRegister.emit(Events.WEBVIEW_ON_LOCAL, { uri, jsInjection });
            return false;
        }
        return true;
    }, []);

    const onMessage = useCallback(({ nativeEvent }) => {
        EventRegister.emit(Events.WEBVIEW_ON_MESSAGE, {
            message: new Message(nativeEvent),
            jsInjection
        });
    }, []);

    //iOS only
    const onFileDownload = useCallback(({ nativeEvent: { downloadUrl } }) => {
        EventRegister.emit(Events.ON_EXTERNAL_LINK_CLICK, { url: downloadUrl });
    }, []);

    /**
     * all active webviews are listening to js injection, so pay attetion before trigger this event
     */
    useEffect(() => {
        const jsInjectId = EventRegister.on(Events.JS_INJECTION, jsInjection);
        return () => {
            EventRegister.rm(jsInjectId);
        };
    }, []);

    const otherProps = {
        ref,
        onShouldStartLoadWithRequest: shouldStartLoad,
        originWhitelist: ["http://", "https://", "xhttp://", "xhttps://", "local://", "file://"],
        onMessage,
        onFileDownload,
        mixedContentMode: "always",
        allowFileAccess: true,
        allowUniversalAccessFromFileURLs: true,
        thirdPartyCookiesEnabled: true,
        domStorageEnabled: true,
        javaScriptEnabled: true,
        bounces: false,
        cacheEnabled: true,
        startInLoadingState: true,
        androidForceHasOverlappingRendering: false,
        messagingEnabled: true,
        ...props
    };

    if (LiveConfig.WebViewComponent) {
        return <LiveConfig.WebViewComponent {...otherProps} />;
    }
    return <RNWebView {...otherProps} />;
}

TaWebView.propTypes = {
    ...WebViewProps
};

export default TaWebView;
