import i18n from "i18n-js";

import en from "./locale/en.json";
import it from "./locale/it.json";
import ar from "./locale/ar.json";
import da from "./locale/da.json";
import de from "./locale/de.json";
import frFR from "./locale/fr-FR.json";
import nlNL from "./locale/nl-NL.json";
import esES from "./locale/es-ES.json";
import roRO from "./locale/ro-RO.json";
import sv from "./locale/sv.json";
import ptPT from "./locale/pt-PT.json";
import ptBR from "./locale/pt-BR.json";
import nlBE from "./locale/nl-BE.json";
import nnNO from "./locale/nn-NO.json";
import nbNO from "./locale/nb-NO.json";
import sl from "./locale/sl.json";

/**
 * languageId = [
 *        '0' => 'EN', '1' => 'IT', '2' => 'DE', '3' => 'FR', '4' => 'NL',
 *        '5' => 'ES', '6' => 'RO', '7' => 'SV', '8' => 'DA', '9' => 'PT',
 *        '10' => 'BR', '11' => 'DU', '12' => 'NN', '13' => 'NO', '14' => 'AR',
 *        '15' => 'SL'
 * ]
 */
const SUPPORTED_LANGUAGES = [
    "en",
    "it",
    "de",
    "fr-FR",
    "nl-NL",
    "es-ES",
    "ro-RO",
    "sv",
    "da",
    "pt-PT",
    "pt-BR",
    "nl-BE",
    "nn-NO",
    "nb-NO",
    "ar",
    "sl"
];

function i18nInit(locale) {
    i18n.locale = locale;
    i18n.fallbacks = true;
    //backupt already in translations
    const translationsBackup = { ...(i18n.translations || {}) };
    //map options page translations
    const translationsLibrary = {
        en,
        it,
        ar,
        da,
        de,
        "fr-FR": frFR,
        "nl-NL": nlNL,
        "es-ES": esES,
        "ro-RO": roRO,
        sv,
        "pt-PT": ptPT,
        "pt-BR": ptBR,
        "nl-BE": nlBE,
        "nn-NO": nnNO,
        "nb-NO": nbNO,
        sl
    };

    //merge all library languages with the same languages in bakcup object
    i18n.translations = Object.keys(translationsLibrary).reduce((translations, libraryKey) => {
        translations[libraryKey] = {
            ...(translationsBackup[libraryKey] || {}),
            ...(translationsLibrary[libraryKey] || {})
        };
        return translations;
    }, {});

    //check if missing some languages from backup and add it
    Object.keys(translationsBackup).forEach((backupKey) => {
        if (!i18n.translations[backupKey]) {
            i18n.translations[backupKey] = {
                ...translationsBackup[backupKey]
            };
        }
    });
}

function i18nLocale() {
    return i18n.locale;
}

function i18nTxt(name, params) {
    return i18n.t(name, params);
}

export { SUPPORTED_LANGUAGES, i18nInit, i18nLocale, i18nTxt };
