import "./utils/polyfill";
/**
 * @format
 */
import React, { useEffect } from "react";
import PropTypes from "prop-types";
import Container from "./Container";
import * as Methods from "./interfaces/methods";
import * as Models from "./interfaces/models";
import { EventRegister } from "./events/manager";
import Events from "./events/events";
import URI from "./models/uri";
import Message from "./models/message";
import { Linking } from "react-native";

function Root(props) {
    const { onLocal, onMessage, onClose, externalLinkCallbacks, ...rest } = props;
    useEffect(() => {
        const onCloseId = EventRegister.on(Events.ON_CLOSE, () => {
            if (typeof onClose === "function") {
                onClose();
            }
        });
        const onLocalId = EventRegister.on(Events.WEBVIEW_ON_LOCAL, (uri: URI) => {
            if (typeof onLocal === "function") {
                onLocal(uri);
            }
        });
        const onMessageId = EventRegister.on(Events.WEBVIEW_ON_MESSAGE, (message: Message) => {
            if (typeof onMessage === "function") {
                onMessage(message);
            }
        });
        const onExternalLinkClickId = EventRegister.on(Events.ON_EXTERNAL_LINK_CLICK, (url) => {
            if (externalLinkCallbacks && typeof externalLinkCallbacks.onClick === "function") {
                externalLinkCallbacks.onClick(url);
            } else {
                Linking.openURL(url);
            }
        });
        return () => {
            EventRegister.rm(onLocalId);
            EventRegister.rm(onMessageId);
            EventRegister.rm(onExternalLinkClickId);
            EventRegister.rm(onCloseId);
        };
    }, []);
    return <Container {...rest} />;
}

Root.propTypes = {
    onClose: PropTypes.func.isRequired,
    onLocal: PropTypes.func,
    onMessage: PropTypes.func,
    externalLinkCallbacks: PropTypes.shape({
        onClick: PropTypes.func
    })
};

export { Methods, Models };
export default Root;
