import React, { useState } from "react";
import { StyleSheet, View } from "react-native";
import PropTypes from "prop-types";
import { Css } from "./components/Css/css";
import Route from "./models/route";
import DrawerNavigator from "./components/Drawer/drawer-navigator";
import { SelectedEditionsContext } from "./data/user-config";
import LiveConfig from "./data/live-config";
import Edition from "./models/edition";

const styles = StyleSheet.create({
    container: {
        height: "100%",
        width: "100%"
    }
});

function Content(props) {
    const { data, ...rest } = props;
    const [selectedEditions, setSelectedEditions] = useState(LiveConfig.getSettings().selectedEditions);

    return (
        <Css classes={["opt-container"]}>
            <SelectedEditionsContext.Provider
                value={{
                    editions: selectedEditions,
                    setEdition: (edition: Edition) => {
                        setSelectedEditions([...LiveConfig.getSettings().addEditionToSelected(edition.getName())]);
                    }
                }}>
                <View style={styles.container}>
                    <DrawerNavigator
                        routes={data.drawerRoutes}
                        initialRoute={data.initialRoute}
                        specials={data.specials}
                        {...rest}
                    />
                </View>
            </SelectedEditionsContext.Provider>
        </Css>
    );
}

Content.propTypes = {
    data: PropTypes.shape({
        drawerRoutes: PropTypes.arrayOf(PropTypes.instanceOf(Route)),
        initialRoute: PropTypes.oneOfType([PropTypes.instanceOf(Route), PropTypes.string]),
        specials: PropTypes.array
    })
};

export default Content;
