import React from "react";
import PropTypes from "prop-types";
import { StyleSheet, Platform, View } from "react-native";
import Modal from "react-native-modal";
import TaCalendar from "./calendar";
import { Css } from "../Css/css";
import CalendarCommons from "./calendar-common";

const styles = StyleSheet.create({
    modal: {
        alignItems: "center"
    },
    container: {
        justifyContent: "center",
        ...Platform.select({
            web: {
                width: "fit-content"
            }
        })
    }
});

function TaCalendarModal(props) {
    const { onClose, visible, ...rest } = props;
    return (
        <Modal
            hasBackdrop
            animationType="fade"
            onBackdropPress={onClose}
            onBackButtonPressonBackButtonPress={onClose}
            isVisible={visible}
            style={styles.modal}>
            <Css classes={["opt-modal-calendar-container"]}>
                <View style={styles.container}>
                    <TaCalendar {...rest} />
                </View>
            </Css>
        </Modal>
    );
}

TaCalendarModal.propTypes = {
    onClose: PropTypes.func.isRequired,
    visible: PropTypes.bool,
    ...CalendarCommons.propTypes
};

TaCalendarModal.defaultProps = {
    visible: false
};

export default TaCalendarModal;
