import React from "react";
import { Calendar, LocaleConfig } from "react-native-calendars";
import LiveConfig from "../../data/live-config";
import DateUtils from "../../utils/date";
import { CARD_RADIUS } from "../Css/common-styles";
import IcArrowLeft from "../Icon/ic-arrow-left";
import IcArrowRight from "../Icon/ic-arrow-right";
import CalendarCommons from "./calendar-common";

function TaCalendar(props) {
    const { date, minDate, maxDate, onDateChange, markedDates, theme } = props;

    //markedDates
    const onChange = ({ timestamp }) => {
        if (typeof onDateChange === "function") {
            onDateChange(new Date(timestamp));
        }
    };

    const others = {};
    if (minDate) {
        others.minDate = DateUtils.formatDate(minDate, "YYYY-MM-DD");
    }
    if (maxDate) {
        others.maxDate = DateUtils.formatDate(maxDate, "YYYY-MM-DD");
    }
    if (date) {
        others.current = DateUtils.formatDate(date, "YYYY-MM-DD");
    }

    if (markedDates) {
        others.markedDates = markedDates.reduce((result, { date: markedDate, ...rest }) => {
            result[DateUtils.formatDate(markedDate, "YYYY-MM-DD")] = rest;
            return result;
        }, {});
        //find dates in which the paper is not published and make those unclickable
        const currentDate = minDate;
        while (currentDate.getTime() < maxDate.getTime()) {
            const currentDateString = DateUtils.formatDate(currentDate, "YYYY-MM-DD");
            if (others.markedDates[currentDateString] === undefined) {
                others.markedDates[currentDateString] = { disabled: true };
            }
            //add one day
            currentDate.setDate(currentDate.getDate() + 1);
        }
    }

    const { language } = LiveConfig.getPSetup();
    const locale = LiveConfig.getLocale();
    LocaleConfig.locales[language] = {
        monthNames: locale.strings("str_month_names").split(","),
        monthNamesShort: locale.strings("str_month_names_short").split(","),
        dayNames: locale.strings("str_day_names").split(","),
        dayNamesShort: locale.strings("str_day_names_short").split(","),
        today: locale.strings("str_today")
    };
    LocaleConfig.defaultLocale = language;

    return (
        <Calendar
            {...others}
            theme={{
                dotColor: theme.dotColor || LiveConfig.getSupportColor(),
                selectedDotColor: theme.selectedDotColor || LiveConfig.getForegroundColor(),
                selectedDayTextColor: theme.selectedDayTextColor || LiveConfig.getForegroundColor(),
                selectedDayBackgroundColor: theme.selectedDayBackgroundColor || LiveConfig.getSupportColor()
            }}
            style={{ borderRadius: CARD_RADIUS, overflow: "hidden" }}
            hideExtraDays
            renderArrow={(direction) => {
                if (direction === "left") {
                    return <IcArrowLeft width={16} />;
                }
                return <IcArrowRight width={16} />;
            }}
            hideArrows={false}
            disableAllTouchEventsForDisabledDays
            onDayPress={onChange}
        />
    );
}

TaCalendar.propTypes = {
    ...CalendarCommons.propTypes
};

TaCalendar.defaultProps = {
    ...CalendarCommons.defaultProps
};

export default TaCalendar;
