import React from "react";
import { View } from "react-native";
import Calendar from "react-calendar";
import CalendarCommons from "./calendar-common";
import DateUtils from "../../utils/date";
import LiveConfig from "../../data/live-config";
import "react-calendar/dist/Calendar.css";
import "./calendar.css";
import IcArrowRight from "../Icon/ic-arrow-right";
import IcArrowLeft from "../Icon/ic-arrow-left";
import { CARD_RADIUS } from "../Css/common-styles";

function TaCalendar(props) {
    const { date, minDate, maxDate, onDateChange, markedDates, theme } = props;
    const onChange = (newValue) => {
        if (typeof onDateChange === "function") {
            onDateChange(newValue);
        }
    };

    const findDate = (item) => {
        return markedDates.find((markDate) => {
            return DateUtils.formatDate(item.date, "YYYY-MM-DD") === DateUtils.formatDate(markDate.date, "YYYY-MM-DD");
        });
    };

    const others = {};
    if (minDate) {
        others.minDate = minDate;
    }
    if (maxDate) {
        others.maxDate = maxDate;
    }
    if (date) {
        others.value = date;
    }

    return (
        <View style={{ borderRadius: CARD_RADIUS, overflow: "hidden" }}>
            <Calendar
                {...others}
                prevLabel={<IcArrowLeft width={16} />}
                nextLabel={<IcArrowRight width={16} />}
                next2Label={null}
                prev2Label={null}
                onChange={onChange}
                tileClassName={(item) => {
                    const found = findDate(item);
                    if (found !== undefined) {
                        if (found.selected) {
                            return "selected";
                        }
                        return "unselected";
                    }
                    return "other";
                }}
                tileDisabled={(item) => {
                    return findDate(item) === undefined;
                }}
                tileContent={(item) => {
                    const found = markedDates.find((markDate) => {
                        return (
                            DateUtils.formatDate(item.date, "YYYY-MM-DD") ===
                            DateUtils.formatDate(markDate.date, "YYYY-MM-DD")
                        );
                    });
                    if (found !== undefined && found.marked) {
                        const dotStyle = {
                            width: 5,
                            height: 5,
                            borderRadius: 5,
                            backgroundColor: theme.dotColor || LiveConfig.getSupportColor()
                        };
                        if (found.selected) {
                            dotStyle.backgroundColor = theme.selectedDotColor || LiveConfig.getForegroundColor();
                        }
                        return (
                            <View style={{ width: "100%", flexDirection: "row", justifyContent: "center" }}>
                                <View style={dotStyle} />
                            </View>
                        );
                    }
                    return null;
                }}
            />
        </View>
    );
}

TaCalendar.propTypes = {
    ...CalendarCommons.propTypes
};

TaCalendar.defaultProps = {
    ...CalendarCommons.defaultProps
};

export default TaCalendar;
