import React, { useEffect, useState } from "react";
import PropTypes from "prop-types";
import { StyleSheet, TouchableOpacity } from "react-native";
import LiveConfig from "../../data/live-config";
import Issue from "../../models/issue";
import EditionsHelper from "../../helpers/editions-helper";
import IcCalendarMonth from "../Icon/ic-calendar-month";
import TaCalendarModal from "../Calendar/calendar-modal";
import DateUtils from "../../utils/date";
import EditionDayHeader from "./edition-day-header";

const styles = StyleSheet.create({
    icon: {
        alignItems: "flex-end",
        width: 50
    }
});

function EditionDaySelector(props) {
    const { selector, issueIndex, issues, onIndexChange, navigation } = props;
    const [showCalender, setShowCalendar] = useState(false);
    const currentIssue = issues[issueIndex];

    useEffect(() => {
        if (!selector) {
            const title = EditionsHelper.getIssueLabel(issues[issueIndex]);
            if (title) {
                navigation.setOptions({ title });
            }
        }
    });

    const show = () => {
        setShowCalendar(true);
    };

    const hide = () => {
        setShowCalendar(false);
    };

    const onDateChange = (date) => {
        const strDate = DateUtils.formatDate(date, "YYYYMMDD");
        const index = issues.findIndex((issue: Issue) => issue.getIssue() === strDate);
        if (typeof onIndexChange === "function") {
            onIndexChange(index);
        }
        hide();
    };

    let Icon = null;
    if (selector) {
        Icon = (
            <TouchableOpacity style={styles.icon} onPress={show}>
                <IcCalendarMonth fill={LiveConfig.getForegroundColor()} />
            </TouchableOpacity>
        );
    }

    return (
        <EditionDayHeader.Container>
            <EditionDayHeader.Body
                text={
                    currentIssue
                        ? currentIssue
                              .getDateLabel()
                              .replace(currentIssue.getDayOfWeek(), currentIssue.getDayOfWeekComplete())
                        : "No issue in this date"
                }>
                {Icon}
                {issues && issues.length >= 2 ? (
                    <TaCalendarModal
                        onClose={hide}
                        visible={showCalender}
                        onDateChange={onDateChange}
                        date={currentIssue ? DateUtils.strToDate(currentIssue.getIssue()) : undefined}
                        minDate={DateUtils.strToDate(issues[issues.length - 1].getIssue())}
                        maxDate={DateUtils.strToDate(issues[0].getIssue())}
                        markedDates={issues.map((issue) => ({
                            date: DateUtils.strToDate(issue.getIssue()),
                            marked: true,
                            selected: currentIssue && currentIssue.getIssue() === issue.getIssue()
                        }))}
                    />
                ) : null}
            </EditionDayHeader.Body>
        </EditionDayHeader.Container>
    );
}

EditionDaySelector.propTypes = {
    selector: PropTypes.bool,
    navigation: PropTypes.shape({
        setOptions: PropTypes.func
    }),
    issueIndex: PropTypes.number,
    onIndexChange: PropTypes.func.isRequired,
    issues: PropTypes.arrayOf(PropTypes.instanceOf(Issue))
};

EditionDaySelector.defaultProps = {
    selector: false,
    issueIndex: 0
};

export default EditionDaySelector;
