import React from "react";
import PropTypes from "prop-types";
import { FlatList, StyleSheet, View } from "react-native";
import { colors } from "../../utils/colors";
import { Css } from "../Css/css";
import EditionCardItem from "./edition-card-item";
import { commonStyles } from "../Css/common-styles";

const styles = StyleSheet.create({
    container: {
        flex: 1
    },
    iconsRow: {
        flexDirection: "row",
        justifyContent: "center"
    },
    iconsContainer: {
        justifyContent: "center",
        alignItems: "center"
    },
    iconContainer: {
        backgroundColor: colors.white,
        borderRadius: 10,
        width: 50,
        height: 50,
        margin: 2,
        justifyContent: "center",
        alignItems: "center"
    }
});

/**
 * edition card that add Icons in overlay
 * @param {*} props
 * @returns
 */
function EditionCardItemWithIcons(props) {
    const { style, iconsContainerStyle, iconContainerStyle, Icons, ...rest } = props;

    return (
        <Css classes={["opt-edition-item-back-container"]}>
            <EditionCardItem style={[styles.container, style]} showGradient={Icons.length > 0} {...rest}>
                {Icons.length ? (
                    <View style={[commonStyles.full, styles.iconsContainer, iconsContainerStyle]}>
                        <View style={styles.iconsRow}>
                            <FlatList
                                listKey={`list_icon_${rest.item.getName()}`}
                                numColumns={2}
                                data={Icons}
                                renderItem={({ item, index }) => (
                                    <View
                                        key={`edition_card_icon_${index}`}
                                        style={[commonStyles.shadow, styles.iconContainer, iconContainerStyle]}>
                                        <Css classes={["opt-edition-item-icon"]}>{item}</Css>
                                    </View>
                                )}
                            />
                        </View>
                    </View>
                ) : null}
            </EditionCardItem>
        </Css>
    );
}

EditionCardItemWithIcons.propTypes = {
    ...EditionCardItem.propTypes,
    Icons: PropTypes.array,
    style: PropTypes.any,
    iconsContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    iconContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array])
};

EditionCardItemWithIcons.defaultProps = {
    ...EditionCardItem.defaultProps,
    Icons: []
};

export default EditionCardItemWithIcons;
