import React from "react";
import PropTypes from "prop-types";
import { TouchableOpacity } from "react-native";
import EditionCardItemWithIcons from "./edition-card-item-with-icons";
import IcHeartMinus from "../Icon/ic-heart-minus";
import IcHeartPlusOutline from "../Icon/ic-heart-plus-outline";

/**
 * component that add a favorite icon and apply the same icon action to all item
 * @param {*} props
 * @returns
 */
function EditionFavoriteItem(props) {
    const { Icons, selected, onFavoriteIconPress, ...rest } = props;
    return (
        <EditionCardItemWithIcons
            Icons={[
                ...Icons,
                <TouchableOpacity onPress={onFavoriteIconPress}>
                    {selected ? <IcHeartMinus /> : <IcHeartPlusOutline />}
                </TouchableOpacity>
            ]}
            onItemPress={onFavoriteIconPress}
            {...rest}
        />
    );
}

EditionFavoriteItem.propTypes = {
    ...EditionCardItemWithIcons.propTypes,
    selected: PropTypes.bool,
    onFavoriteIconPress: PropTypes.func.isRequired
};

EditionFavoriteItem.defaultProps = {
    ...EditionCardItemWithIcons.defaultProps,
    selected: false
};

export { EditionFavoriteItem };
