import React from "react";
import PropTypes from "prop-types";
import { Image, StyleSheet, TouchableOpacity } from "react-native";
import IcNewspaperMultiple from "../Icon/ic-newspaper-multiple";
import EditionCardItemWithIcons from "./edition-card-item-with-icons";
import { colors } from "../../utils/colors";
import { EditionFavoriteItem } from "./edition-favorite-item";

const styles = StyleSheet.create({
    icon: {
        width: 30,
        height: 30
    }
});

/**
 * component that add a folder icon and apply the same icon action to all item
 * add also favorite icon if enableFavorite prop is true
 * @param {*} props
 * @returns
 */
function EditionFolderItem(props) {
    const { enableFavorite, onFolderIconPress, Icons, ...rest } = props;
    let Img = null;
    if (rest.item && rest.item.getIcon()) {
        Img = <Image source={{ uri: rest.item.getIcon() }} style={[styles.icon, { tintColor: colors.black }]} />;
    } else {
        Img = <IcNewspaperMultiple />;
    }

    Img = <TouchableOpacity onPress={onFolderIconPress}>{Img}</TouchableOpacity>;

    if (enableFavorite) {
        return <EditionFavoriteItem Icons={[...Icons, Img]} onItemPress={onFolderIconPress} {...rest} />;
    }
    return <EditionCardItemWithIcons Icons={[...Icons, Img]} onItemPress={onFolderIconPress} {...rest} />;
}

EditionFolderItem.propTypes = {
    ...EditionCardItemWithIcons.propTypes,
    enableFavorite: PropTypes.bool,
    onFolderIconPress: PropTypes.func.isRequired
};

EditionFolderItem.defaultProps = {
    ...EditionCardItemWithIcons.defaultProps,
    enableFavorite: true
};

export { EditionFolderItem };
