import React, { useCallback } from "react";
import PropTypes from "prop-types";
import { commonStyles } from "../Css/common-styles";
import Edition from "../../models/edition";
import BaseItem from "../Item/base-item";
import EditionsHelper from "../../helpers/editions-helper";
import BaseItemWithImage from "../Item/base-item-with-image";

function editionItemKey(item: Edition, index) {
    return `${item.getName()}_${index}`;
}

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function EditionItem(props) {
    const { item, showThumbnail, onItemPress, ...rest }: { item: Edition } = props;

    const onPress = useCallback(() => {
        if (typeof onItemPress === "function") {
            onItemPress(item);
        }
    }, []);

    if (!item) {
        return null;
    }

    const Component = showThumbnail ? BaseItemWithImage : BaseItem;

    return (
        <Component
            {...rest}
            item={EditionsHelper.getFirstValidIssue([item])}
            onPress={onPress}
            badgeText={item.getLabel()}
        />
    );
}

EditionItem.propTypes = {
    ...BaseItem.propTypes,
    ...BaseItemWithImage.propTypes,
    item: PropTypes.instanceOf(Edition).isRequired,
    showThumbnail: PropTypes.bool,
    textStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    onItemPress: PropTypes.func,
    children: PropTypes.any
};

EditionItem.defaultProps = {
    ...BaseItem.defaultProps,
    ...BaseItemWithImage.defaultProps,
    style: commonStyles.container,
    showThumbnail: true
};

export { editionItemKey };
export default EditionItem;
