import React from "react";
import PropTypes from "prop-types";
import Edition from "../../models/edition";
import IssueList from "../List/issue-list";
import EditionList from "../List/edition-list";
import LiveConfig from "../../data/live-config";
import Issue from "../../models/issue";

function EditionsNested(props) {
    const { main, issueCallbacks } = props;

    let ComponentList = null;
    const editions = main.getGroup();
    if (editions.length > 1) {
        const { showMultiEditionsFlat } = LiveConfig.getPSetup();
        if (showMultiEditionsFlat) {
            const issuesList = editions
                .reduce((prev, edition) => {
                    prev.push(...edition.getIssues());
                    return prev;
                }, [])
                .sort((issueA: Issue, issueB: Issue) => issueB.getIssue() - issueA.getIssue());
            ComponentList = <IssueList horizontal={false} issues={issuesList} issueCallbacks={issueCallbacks} />;
        } else {
            ComponentList = <EditionList horizontal={false} edition={main} issueCallbacks={issueCallbacks} />;
        }
    } else if (editions.length) {
        ComponentList = (
            <IssueList horizontal={false} issues={editions[0].getIssues()} issueCallbacks={issueCallbacks} />
        );
    } else {
        ComponentList = <IssueList horizontal={false} issues={main.getIssues()} issueCallbacks={issueCallbacks} />;
    }
    return ComponentList;
}

EditionsNested.propTypes = {
    main: PropTypes.instanceOf(Edition)
};

EditionsNested.defaultProps = {};

export default EditionsNested;
