import React from "react";
import PropTypes from "prop-types";
import { StyleSheet, View, TouchableOpacity } from "react-native";
import IcClose from "../Icon/ic-close";
import TaText from "../Tecnavia/ta-text";
import { colors } from "../../utils/colors";
import LiveConfig from "../../data/live-config";
import Edition from "../../models/edition";
import { commonStyles } from "../Css/common-styles";

const styles = StyleSheet.create({
    container: {
        flexDirection: "row",
        flexWrap: "wrap",
        padding: 5
    },
    buttonContainer: {
        flexDirection: "row",
        alignItems: "center",
        //justifyContent: "center",
        paddingHorizontal: 10,
        paddingVertical: 5,
        margin: 5,
        borderRadius: 50
    },
    touchable: {},
    text: {
        fontSize: 15,
        color: colors.black
    }
});

function EditionsTags(props) {
    const { tags, onTagPress } = props;
    return (
        <View style={styles.container}>
            {tags.map((tag, index) => (
                <View
                    key={`tag_${tag.getName()}_${index}`}
                    style={[
                        commonStyles.shadow,
                        styles.buttonContainer,
                        { backgroundColor: LiveConfig.getSupportColor() }
                    ]}>
                    <TouchableOpacity
                        style={[styles.touchable]}
                        onPress={() => {
                            if (typeof onTagPress === "function") {
                                onTagPress(tag);
                            }
                        }}>
                        <IcClose fill={LiveConfig.getForegroundColor()} width={16} height={16} />
                    </TouchableOpacity>
                    <TaText style={[styles.text, { color: LiveConfig.getForegroundColor() }]}>{tag.getLabel()}</TaText>
                </View>
            ))}
        </View>
    );
}

EditionsTags.propTypes = {
    tags: PropTypes.arrayOf(PropTypes.instanceOf(Edition)),
    onTagPress: PropTypes.func.isRequired
};

EditionsTags.defaultProps = {
    tags: []
};

export default EditionsTags;
