import React, { useEffect, useRef } from "react";
import PropTypes from "prop-types";
import { Animated, StyleSheet, TouchableOpacity } from "react-native";
import { colors } from "../../utils/colors";
import { ANIMATION_DURATION, commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import TaImageIcon from "../Tecnavia/ta-image-icon";
import ErrorIcon from "./error-icon";
import TaText from "../Tecnavia/ta-text";
import IcCloseCircleOutline from "../Icon/ic-close-circle-outline";

const styles = StyleSheet.create({
    container: {
        width: "100%",
        flexDirection: "row",
        alignItems: "center",
        margin: 5,
        borderRadius: 5,
        padding: 10,
        backgroundColor: colors.grey900
    },
    separator: {
        height: 20,
        width: 1,
        margin: 5,
        backgroundColor: colors.grey300
    },
    text: {
        flex: 1,
        padding: 10,
        color: colors.white
    },
    touchable: {
        justifyContent: "center"
    }
});

function Error(props) {
    const { error, onRemove } = props;
    const animated = useRef(new Animated.Value(0)).current;

    useEffect(() => {
        Animated.timing(animated, {
            toValue: 1,
            duration: ANIMATION_DURATION,
            useNativeDriver: false
        }).start();
    }, []);

    const onPress = () => {
        if (typeof onRemove === "function") {
            Animated.timing(animated, {
                toValue: 0,
                duration: ANIMATION_DURATION,
                useNativeDriver: false
            }).start(({ finished }) => {
                if (finished) {
                    onRemove();
                }
            });
        }
    };

    return (
        <Css classes={["opt-error-container"]}>
            <Animated.View
                style={[
                    styles.container,
                    {
                        opacity: animated,
                        transform: [{ scale: animated }]
                    },
                    commonStyles.shadow
                ]}>
                <ErrorIcon type={error.type} />
                <Css classes={["opt-error-text"]}>
                    <TaText style={styles.text}>{error.text}</TaText>
                </Css>
                <Css classes={["opt-error-close-container"]}>
                    <TouchableOpacity style={styles.touchable} onPress={onPress}>
                        <Css classes={["opt-error-close"]}>
                            <TaImageIcon
                                style={styles.icon}
                                DefaultComponent={<IcCloseCircleOutline fill={colors.grey400} width={25} height={25} />}
                            />
                        </Css>
                    </TouchableOpacity>
                </Css>
            </Animated.View>
        </Css>
    );
}

Error.propTypes = {
    error: PropTypes.shape({
        text: PropTypes.string,
        type: PropTypes.number
    }).isRequired,
    onRemove: PropTypes.func.isRequired
};

export default Error;
