/* eslint-disable no-shadow */
import React, { useEffect, useState } from "react";
import PropTypes from "prop-types";
import { StyleSheet, View } from "react-native";
import { EventRegister } from "../../events/manager";
import Events from "../../events/events";
import Error from "./error-view";
import Logger from "../../utils/log";
import { toMD5 } from "../../utils/strings";
import { Css } from "../Css/css";

const styles = StyleSheet.create({
    container: {
        alignItems: "flex-end",
        padding: 10
    },
    content: {
        maxWidth: 500
    }
});

function Errors(props) {
    const { style } = props;
    const [errors, setErrors] = useState([]);

    useEffect(() => {
        const onError = EventRegister.on(Events.ON_ERROR, ({ error }) => {
            Logger.debug(`add ${error} to errors view`);
            setErrors([...errors, error]);
        });
        return () => {
            if (onError) {
                EventRegister.rm(onError);
            }
        };
    }, [errors]);

    return (
        <Css classes={["opt-errors-container"]}>
            <View style={[styles.container, style]}>
                <Css classes={["opt-errors-list"]}>
                    <View style={[styles.content]}>
                        {errors.map((error, index) => (
                            <Error
                                key={`error_${toMD5(error.text)}`}
                                error={error}
                                onRemove={() => {
                                    setErrors((prevErrors) => {
                                        const deletedErrors = prevErrors.splice(index, 1);
                                        Logger.debug(`remove ${deletedErrors} from errros`);
                                        return [...prevErrors];
                                    });
                                }}
                            />
                        ))}
                    </View>
                </Css>
            </View>
        </Css>
    );
}

Errors.propTypes = {
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array])
};

export default Errors;
