import React, { useCallback, useState } from "react";
import { StyleSheet, View } from "react-native";
import PropTypes from "prop-types";

const styles = StyleSheet.create({
    container: {
        flexDirection: "row",
        flexWrap: "wrap"
    }
});

function Grid(props) {
    const { data, style, renderItem, baseItemSize, numberOfColumns, columnMargin } = props;

    const [layout, setLayout] = useState();
    const onLayout = useCallback(({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    });

    let GridElements = null;
    if (layout) {
        const { width } = layout;

        let numColumns = 1;
        let itemWidth;
        let itemHeight;
        if (baseItemSize) {
            ({ width: itemWidth, height: itemHeight } = baseItemSize);
            const aspectRatio = itemWidth / itemHeight;
            numColumns = Math.floor(width / itemWidth);

            const availableRightSpace = width - (itemWidth * numColumns + columnMargin * (numColumns - 1));
            if (availableRightSpace < itemWidth * 0.6) {
                itemWidth += Math.floor(availableRightSpace / numColumns);
                itemHeight = itemWidth / aspectRatio;
            } else if (availableRightSpace > itemWidth * 0.6) {
                numColumns += 1;
                itemWidth = Math.floor((width - columnMargin * (numColumns - 1)) / numColumns);
                itemHeight = itemWidth / aspectRatio;
            }
        } else if (numberOfColumns) {
            numColumns = numberOfColumns;
            itemWidth = (width - columnMargin * (numColumns - 1)) / numColumns;
        }

        GridElements = data.map((item, index) => {
            const parentStyle = [];
            if (numColumns > 1) {
                //ensure a margin between tiles
                if (index % numColumns === 0) {
                    parentStyle.push({ marginRight: columnMargin / 2 });
                } else if ((index + 1) % numColumns === 0) {
                    parentStyle.push({ marginLeft: columnMargin / 2 });
                } else {
                    parentStyle.push({ marginHorizontal: columnMargin / 2 });
                }
            }
            return (
                <View key={`grid_item${index}`} style={[{ width: itemWidth, height: itemHeight }, parentStyle]}>
                    {renderItem(item)}
                </View>
            );
        });
    }

    return (
        <View style={[styles.container, style]} onLayout={onLayout}>
            {GridElements}
        </View>
    );
}
Grid.propTypes = {
    data: PropTypes.array.isRequired,
    renderItem: PropTypes.func.isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    baseItemSize: PropTypes.object,
    numberOfColumns: PropTypes.number,
    columnMargin: PropTypes.number
};

Grid.defaultProps = {
    columnMargin: 10
};

export default Grid;
