import React, { useState } from "react";
import PropTypes from "prop-types";
import { Platform, View } from "react-native";
import IssueList from "../List/issue-list";
import Issue from "../../models/issue";
import { MAX_SCREEN_WIDTH } from "../Css/common-styles";
import IssueCardItem from "../IssueItem/issue-card-item";
import Grid from "./grid";

/**
 * display horizontal list of secondary editions
 * display secondary editions add button
 * @param {*} props
 * @returns
 */
function IssuesGrid(props) {
    const { data, issueCallbacks, issueSize, EmptyComponent } = props;
    const [layout, setLayout] = useState();

    const onLayout = ({ nativeEvent }) => {
        setLayout(nativeEvent.layout);
    };

    let ListComponent = null;
    const newDataSet = [...data];
    if (layout) {
        let showPlusAtBottom = false;
        if (EmptyComponent) {
            if (layout.width >= 450 || data.length) {
                const plusIssue = new Issue();
                plusIssue.setIssue("plus");
                plusIssue.setEdition("plus");
                newDataSet.push({ issue: plusIssue, label: "plus" });
            } else {
                showPlusAtBottom = true;
            }
        }

        ListComponent = (
            <>
                <Grid
                    data={newDataSet}
                    baseItemSize={issueSize}
                    renderItem={({ issue, label }) => {
                        if (issue.getIssue() === "plus" && issue.getEdition() === "plus") {
                            return EmptyComponent;
                        }
                        return (
                            <IssueCardItem
                                style={Platform.select({
                                    native: { marginHorizontal: 0 }
                                })}
                                item={issue}
                                showHighRes
                                issueCallbacks={issueCallbacks}
                                textFormat={label}
                            />
                        );
                    }}
                />
                {showPlusAtBottom ? (
                    <View style={{ flex: 0, height: 50, marginBottom: 30 }}>{EmptyComponent}</View>
                ) : null}
            </>
        );
    }

    return (
        <View onLayout={onLayout} style={{ width: "100%", maxWidth: MAX_SCREEN_WIDTH }}>
            {ListComponent}
        </View>
    );
}

IssuesGrid.defaultProps = {
    EmptyComponent: null,
    issueSize: {
        width: 150,
        height: 200
    }
};

IssuesGrid.propTypes = {
    data: PropTypes.arrayOf(PropTypes.shape({ issue: PropTypes.instanceOf(Issue), label: PropTypes.string })),
    issueSize: PropTypes.object,
    EmptyComponent: PropTypes.any,
    ...IssueList.propTypes
};

export default IssuesGrid;
