import React from "react";
import PropTypes from "prop-types";
import { StyleSheet, TouchableOpacity, View } from "react-native";
import { colors } from "../../utils/colors";
import { Css } from "../Css/css";
import TaImageIcon from "../Tecnavia/ta-image-icon";
import { HEADER_HEIGHT } from "../Css/common-styles";
import LiveConfig from "../../data/live-config";

//const logoId = require("../../img/header-logo.png");

const styles = StyleSheet.create({
    parent: {
        flex: 1,
        height: HEADER_HEIGHT,
        justifyContent: "center",
        alignItems: "flex-start",
        padding: 10
    },
    logo: {
        width: "100%",
        height: "100%",
        resizeMode: "contain"
    }
});

function Logo(props) {
    const { backgroundColor, Component, onLogoPress } = props;

    let ToRender = null;
    if (typeof Component === "string") {
        ToRender = <TaImageIcon style={styles.logo} source={{ uri: Component }} />;
    } else if (typeof Component === "function") {
        ToRender = Component({ style: styles.logo });
    } else if (Component != null) {
        ToRender = Component;
    } else {
        ToRender = <TaImageIcon style={styles.logo} source={{ uri: LiveConfig.getPSetup().logoUrl }} />;
    }
    const Container = typeof onLogoPress === "function" ? TouchableOpacity : View;
    return (
        <Css classes={["opt-logo-parent"]}>
            <Container style={[styles.parent, { backgroundColor }]} onPress={onLogoPress}>
                <Css classes={["opt-logo"]}>{ToRender}</Css>
            </Container>
        </Css>
    );
}

Logo.propTypes = {
    backgroundColor: PropTypes.string,
    Component: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.node]),
    onLogoPress: PropTypes.func
};

Logo.defaultProps = {
    backgroundColor: colors.white,
    Component: null
};

export default Logo;
