import React from "react";
import PropTypes from "prop-types";
import Issue from "../../models/issue";
import { commonStyles } from "../Css/common-styles";
import BaseItemWithImage from "../Item/base-item-with-image";

function issueItemKey(item: Issue, index) {
    return `${item.getIssue()}_${index}`;
}

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function IssueItem(props) {
    const { issueCallbacks, textFormat, item, ...rest } = props;

    const { onIssuePress } = issueCallbacks;

    if (!item) {
        return null;
    }

    return (
        <BaseItemWithImage
            {...rest}
            item={item}
            onPress={onIssuePress}
            badgeText={textFormat.replace("edition", item.getEditionLabel()).replace("issue", item.getDateLabel())}
        />
    );
}

IssueItem.propTypes = {
    item: PropTypes.instanceOf(Issue).isRequired,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageParentStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageGraphStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageTextStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    issueCallbacks: PropTypes.shape({
        onIssuePress: PropTypes.func
    }),
    textFormat: PropTypes.string,
    hideTitle: PropTypes.bool,
    showHighRes: PropTypes.bool,
    cssPrefix: PropTypes.string,
    ...BaseItemWithImage.propTypes
};

IssueItem.defaultProps = {
    style: commonStyles.container,
    issueCallbacks: {},
    cssPrefix: "",
    textFormat: "issue",
    showHighRes: false,
    hideTitle: false
};

export { issueItemKey };
export default IssueItem;
