import React from "react";
import PropTypes from "prop-types";
import { View, StyleSheet } from "react-native";
import LinearGradient from "react-native-linear-gradient";
import Issue from "../../models/issue";
import { commonStyles } from "../Css/common-styles";
import { Css, CssHelper } from "../Css/css";
import IssueImage from "../IssueImage/issue-image";
import BaseItem from "./base-item";
import { colors } from "../../utils/colors";

const styles = StyleSheet.create({
    imageParent: {
        flex: 1
    },
    gradient: {
        position: "absolute",
        top: 0,
        left: 0,
        right: 0,
        bottom: 0
    }
});

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function BaseItemWithImage(props) {
    const {
        item,
        cssPrefix,
        imageParentStyle,
        imageStyle,
        imageGraphStyle,
        imageTextStyle,
        showHighRes,
        children,
        showGradient,
        ...rest
    }: { item: Issue } = props;

    const {
        backgroundColor: gradientColors = [colors.white_transparent_0, colors.white_transparent_40, colors.white],
        ...otherGradientStyles
    } = CssHelper.getStyleObjByCssClasses(["opt-issue-item-image-gradient"], { cssKey: cssPrefix });

    return (
        <BaseItem {...rest} item={item} cssPrefix={cssPrefix}>
            <Css classes={["opt-issue-item-image-container"]} cssKey={cssPrefix}>
                <View style={[styles.imageParent, imageParentStyle]}>
                    <Css classes={["opt-issue-item-image"]} cssKey={cssPrefix}>
                        <IssueImage
                            showHighRes={showHighRes}
                            item={item}
                            style={imageStyle}
                            graphStyle={CssHelper.flatten([imageGraphStyle], ["opt-issue-item-image-graph"], {
                                cssKey: cssPrefix
                            })}
                            textStyle={CssHelper.flatten([imageTextStyle], ["opt-issue-item-image-text"], {
                                cssKey: cssPrefix
                            })}
                        />
                    </Css>
                    {showGradient ? (
                        <LinearGradient style={[styles.gradient, otherGradientStyles]} colors={gradientColors} />
                    ) : null}
                </View>
            </Css>
            {children}
        </BaseItem>
    );
}

BaseItemWithImage.propTypes = {
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageParentStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageGraphStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    imageTextStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    showHighRes: PropTypes.bool,
    showGradient: PropTypes.bool,
    ...BaseItem.propTypes
};

BaseItemWithImage.defaultProps = {
    style: commonStyles.container,
    showHighRes: false
};

export default BaseItemWithImage;
