import React, { useCallback } from "react";
import PropTypes from "prop-types";
import { View, Pressable } from "react-native";
import Issue from "../../models/issue";
import { commonStyles } from "../Css/common-styles";
import { Css } from "../Css/css";
import Badge from "./badge";

/**
 * return issue images
 * could be low.jpg or high res by overriding graph.gpj with text.gif
 * @param {*} props
 * @returns
 */
function BaseItem(props) {
    const {
        item,
        cssPrefix,
        style,
        footerParentStyle,
        onPress,
        badgeText,
        hideTitle,
        children,
        isTouchable
    }: { item: Issue } = props;

    const onItemPress = useCallback(() => {
        if (typeof onPress === "function") {
            onPress(item);
        }
    }, [item]);

    if (!item) {
        return null;
    }

    const Component = isTouchable ? Pressable : View;
    return (
        <Css classes={["opt-issue-item-container"]} cssKey={cssPrefix}>
            <Component style={style} onPress={onItemPress}>
                {children}
                {!hideTitle ? (
                    <Badge
                        text={badgeText}
                        footerParentStyle={footerParentStyle}
                        cssPrefix={cssPrefix}
                        showDownloadCheck={item.isDownloaded()}
                    />
                ) : null}
            </Component>
        </Css>
    );
}

BaseItem.propTypes = {
    item: PropTypes.instanceOf(Issue).isRequired,
    onPress: PropTypes.func,
    style: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    hideTitle: PropTypes.bool,
    cssPrefix: PropTypes.string,
    badgeText: PropTypes.string,
    isTouchable: PropTypes.bool,
    ...Badge.propTypes
};

BaseItem.defaultProps = {
    style: commonStyles.container,
    cssPrefix: "",
    hideTitle: false,
    isTouchable: true,
    badgeText: ""
};

export default BaseItem;
