import React from "react";
import PropTypes from "prop-types";
import { View, StyleSheet } from "react-native";
import { colors } from "../../utils/colors";
import { HEADER_HEIGHT } from "../Css/common-styles";
import { Css } from "../Css/css";
import TaText from "../Tecnavia/ta-text";
import TaImageIcon from "../Tecnavia/ta-image-icon";

const styles = StyleSheet.create({
    header: {
        height: HEADER_HEIGHT,
        backgroundColor: colors.white,
        alignItems: "center",
        //justifyContent: "center",
        flexDirection: "row"
    },
    text: {
        color: colors.black,
        fontSize: 20,
        fontWeight: "bold"
    },
    left: {
        flex: 1,
        paddingHorizontal: 15,
        flexDirection: "row",
        alignItems: "center"
    },
    right: {}
});

/**
 * render simple header component to display a text
 * @param {*} props
 * @returns
 */
function HeaderList(props) {
    const { title, Icon, TextComponent, RightComponent } = props;
    if (!title && !TextComponent) {
        return null;
    }
    return (
        <Css classes={["opt-header-container"]}>
            <View style={styles.header}>
                <Css classes={["opt-header-left"]}>
                    <View style={styles.left}>
                        <Css classes={["opt-header-icon"]}>
                            <TaImageIcon DefaultComponent={Icon} />
                        </Css>
                        <Css classes={["opt-header-text"]}>
                            {TextComponent || <TaText style={styles.text}>{title}</TaText>}
                        </Css>
                    </View>
                </Css>
                <Css classes={["opt-header-right"]}>
                    <View style={styles.right}>{RightComponent || null}</View>
                </Css>
            </View>
        </Css>
    );
}
HeaderList.propTypes = {
    title: PropTypes.string,
    Icon: PropTypes.node,
    TextComponent: PropTypes.node,
    RightComponent: PropTypes.node
};

export default HeaderList;
