import React from "react";
import PropTypes from "prop-types";
import { FlatList, Platform, StyleSheet, View } from "react-native";
import { commonStyles } from "../Css/common-styles";
import HeaderList from "./header-list";
import { Css, CssHelper } from "../Css/css";

const styles = StyleSheet.create({
    list: {
        ...Platform.select({
            web: {
                overflow: "auto"
            }
        })
    }
});

/**
 * render issue list in an horizontal mode
 * @param {*} props
 * @returns
 */
function HorizontalList(props) {
    const { title, HeaderComponent, horizontalContainerStyle, renderItem, itemSize, ...rest } = props;

    return (
        <Css classes={["opt-issues-container", "opt-issues-container-horizontal"]}>
            <View
                style={[commonStyles.container, commonStyles.card, commonStyles.shadow, horizontalContainerStyle]}
                collapsable={false}>
                {HeaderComponent ? HeaderComponent : <HeaderList title={title} />}
                <Css classes={["opt-issues-list", "opt-issues-list-horizontal"]}>
                    <FlatList
                        key="edition_list_cols"
                        horizontal
                        contentContainerStyle={CssHelper.flatten(
                            [styles.list],
                            ["opt-issues-list-container", "opt-issues-list-container-horizontal"]
                        )}
                        renderItem={({ item, index }) => renderItem({ item, index, style: [itemSize], size: itemSize })}
                        {...rest}
                    />
                </Css>
            </View>
        </Css>
    );
}

HorizontalList.propTypes = {
    horizontalContainerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    itemSize: PropTypes.shape({
        width: PropTypes.number,
        height: PropTypes.number
    }),
    data: PropTypes.array.isRequired,
    title: PropTypes.string,
    HeaderComponent: PropTypes.node,
    renderItem: PropTypes.func.isRequired,
    keyExtractor: PropTypes.func.isRequired
};

export default HorizontalList;
