import React from "react";
import PropTypes from "prop-types";
import Issue from "../../models/issue";
import IssueItem, { issueItemKey } from "../IssueItem/issue-item";
import List from "./list";
import IssueCardItem from "../IssueItem/issue-card-item";
import IssueFlatItem from "../IssueItem/issue-flat-item";
import LayoutList from "./layout-list";
import { THUMBNAIL_HR_THRESHOLD } from "./list-utils";
import { AspectRatioContext } from "../Context/context";

/**
 * component that choose wich kind of list render
 * evaluate also item size by checking first issue aspect ratio and parent constraint
 * @param {*} props
 * @returns
 */
function IssueList(props) {
    const { horizontal, issues, issueCallbacks, useLayoutList, itemStyle, showHighRes, ...rest } = props;

    const commonItemProps = {
        style: itemStyle,
        issueCallbacks
    };

    const commonProps = {
        horizontal,
        data: issues,
        keyExtractor: issueItemKey,
        renderVerticalItem: ({ size, ...itemProps }) => (
            <IssueCardItem
                {...itemProps}
                {...commonItemProps}
                showHighRes={showHighRes || size.height > THUMBNAIL_HR_THRESHOLD}
            />
        ),
        renderHorizontalItem: ({ size, ...itemProps }) => (
            <IssueFlatItem
                {...itemProps}
                {...commonItemProps}
                showHighRes={showHighRes || size.height > THUMBNAIL_HR_THRESHOLD}
            />
        ),
        ...rest
    };

    if (useLayoutList) {
        return (
            <AspectRatioContext.Consumer>
                {(value) => <LayoutList {...commonProps} aspectRatio={value} />}
            </AspectRatioContext.Consumer>
        );
    }
    return <List {...commonProps} />;
}

IssueList.propTypes = {
    horizontal: PropTypes.bool,
    removeClippedSubviews: PropTypes.bool,
    initialNumToRender: PropTypes.number,
    issues: PropTypes.arrayOf(PropTypes.instanceOf(Issue)),
    issueCallbacks: IssueItem.propTypes.issueCallbacks,
    useLayoutList: PropTypes.bool,
    itemStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object, PropTypes.array]),
    showHighRes: PropTypes.bool
};

IssueList.defaultProps = {
    horizontal: true,
    initialNumToRender: 5,
    removeClippedSubviews: true,
    useLayoutList: true,
    showHighRes: false
};

export default IssueList;
