import React from "react";
import PropTypes from "prop-types";
import { createMaterialTopTabNavigator } from "@react-navigation/material-top-tabs";
import RouteEditionsDate from "../../models/route-editions-date";
import RouteEdition from "../../models/route-edition";
import EditionsNested from "../EditionsNested/editions-nested";
import LiveConfig from "../../data/live-config";
import IssueItem from "../IssueItem/issue-item";
import EditionDayContainer from "../EditionDayPage/edition-day-container";
import RouteUrl from "../../models/route-url";
import UrlPage from "../UrlPage/url-page";
import TabBar from "./tab-bar";

const Tab = createMaterialTopTabNavigator();

function renderTabScreens({ routes, props = {} }) {
    const screens = [];
    routes.forEach((route) => {
        const ScreenProps = {
            name: route.getText(),
            key: route.getRoute(),
            options: {
                tabBarLabel: route.getText().toUpperCase()
            }
        };
        let Component = null;
        if (route instanceof RouteEditionsDate) {
            Component = (
                <Tab.Screen {...ScreenProps}>
                    {(navProps) => (
                        <EditionDayContainer
                            main={route}
                            {...props}
                            {...navProps}
                            horizontal={LiveConfig.isWideScreen()}
                        />
                    )}
                </Tab.Screen>
            );
        } else if (route instanceof RouteEdition) {
            Component = (
                <Tab.Screen {...ScreenProps}>
                    {(navProps) => <EditionsNested main={route.getEdition()} {...props} {...navProps} />}
                </Tab.Screen>
            );
        } else if (route instanceof RouteUrl) {
            Component = (
                <Tab.Screen {...ScreenProps}>
                    {(navProps) => <UrlPage url={route.getUrl()} {...props} {...navProps} canUseCustomComponent />}
                </Tab.Screen>
            );
        }

        if (Component) {
            screens.push(Component);
        }
    });
    return screens;
}

function TabNavigator(props) {
    const { routes, initialRouteName, specials, issueCallbacks, viewSize } = props;

    return (
        <Tab.Navigator
            initialRouteName={initialRouteName}
            tabBar={(tabProps) => (
                <TabBar
                    backgroundColor={LiveConfig.getSupportColor()}
                    textColor={LiveConfig.getForegroundColor()}
                    screenWidth={viewSize.width}
                    {...tabProps}
                />
            )}
            screenOptions={{
                //tabBarScrollEnabled: true,
                lazy: true,
                lazyPreloadDistance: 1
            }}
            backBehavior="initialRoute">
            {renderTabScreens({ routes, props: { specials, issueCallbacks } })}
        </Tab.Navigator>
    );
}

TabNavigator.propTypes = {
    routes: PropTypes.array,
    initialRouteName: PropTypes.string,
    specials: PropTypes.array,
    viewSize: PropTypes.shape({
        width: PropTypes.number,
        height: PropTypes.number
    }),
    issueCallbacks: IssueItem.propTypes.issueCallbacks
};
export default TabNavigator;
