import React from "react";
import { Animated, Image, ImageProps } from "react-native";
import PropTypes from "prop-types";
import FSImage from "./fs-image";
import CssStyle from "../Css/css-styles";
import { isIOS } from "../../utils/platform";
import { Svg } from "../Icon/ta-svg";

function mapPropsOnComponent(props) {
    const { style, imageStyle, source, tintColor, ...rest } = props;
    const paths = CssStyle.getAttributeFromStyle("paths", style, []);
    const src = CssStyle.getAttributeFromStyle("src", style, "");

    const newProps = {
        Component: null,
        ...rest
    };
    const useSvg = paths && paths.length;
    const srcStyleIsValid = src && src.length;
    const srcPropIsValid = typeof source === "number" || (source && source.uri) || false;
    if (useSvg) {
        newProps.Component = Svg;
        newProps.style = style;
    } else if (srcPropIsValid || srcStyleIsValid) {
        newProps.Component = isIOS() ? FSImage : Image;
        newProps.style = CssStyle.deleteKeysFromStyle([imageStyle, style], ["color"]);
        newProps.source = source || src;
        newProps.tintColor = tintColor;
    }
    return newProps;
}

class TaImageIcon extends React.Component {
    render() {
        const { Component, DefaultComponent, ...rest } = mapPropsOnComponent(this.props);
        if (Component) {
            return <Component {...rest} />;
        }
        return DefaultComponent;
    }
}

TaImageIcon.propTypes = {
    style: PropTypes.any,
    imageStyle: PropTypes.any,
    iconStyle: PropTypes.any,
    size: PropTypes.number,
    tintColor: PropTypes.string,
    DefaultComponent: PropTypes.node,
    ...ImageProps
};

TaImageIcon.defaultProps = {
    DefaultComponent: null
};

const TaAnimatedImageIcon = Animated.createAnimatedComponent(TaImageIcon);

export { TaAnimatedImageIcon };
export default TaImageIcon;
