import React from "react";
import PropTypes from "prop-types";
import { StyleSheet, View } from "react-native";
import { useIsFocused } from "@react-navigation/native";
import TaWebView from "../WebView/webview";
import Network from "../../utils/network";
import TaText from "../Tecnavia/ta-text";
import LiveConfig from "../../data/live-config";
import IcWebOff from "../Icon/ic-web-off";

const styles = StyleSheet.create({
    webview: {
        height: "100%",
        padding: 0
    }
});

function UrlPage(props) {
    const { url, canUseCustomComponent } = props;
    const isFocused = useIsFocused();

    if (!isFocused) {
        return null;
    }
    if (url) {
        if (Network.isOnline()) {
            return (
                <TaWebView
                    source={{ uri: url }}
                    style={styles.webview}
                    active
                    canUseCustomComponent={canUseCustomComponent}
                />
            );
        }
        return (
            <View style={{ flex: 1, justifyContent: "center", alignItems: "center" }}>
                <IcWebOff width={50} height={50} />
                <TaText style={{ marginTop: 15 }}>{LiveConfig.getLocale().strings("str_not_available_offline")}</TaText>
            </View>
        );
    }
    return null;
}

UrlPage.propTypes = {
    url: PropTypes.string.isRequired,
    canUseCustomComponent: PropTypes.bool
};

UrlPage.defaultProps = {
    canUseCustomComponent: false
};

export default UrlPage;
