import { DrawerActions, NavigationState } from "@react-navigation/native";

function getActiveRouteFromState(state = {}) {
    const { index, routes = [] } = state;
    const route = routes[index];
    if (route) {
        return route.name;
    }
    return undefined;
}

class NavigationConfig {
    static drawerOpened: Boolean;
    static navigation: Object;
    static state: NavigationState;

    static setState(state: NavigationState) {
        NavigationConfig.state = state;
    }

    static getState(): NavigationState {
        return NavigationConfig.state;
    }

    static isDrawerOpened(): Boolean {
        return NavigationConfig.drawerOpened;
    }

    static setDrawerState(open: Boolean) {
        NavigationConfig.drawerOpened = open;
    }

    static getNavigation(): Object {
        return NavigationConfig.navigation;
    }

    static setNavigation(navigation: Object) {
        NavigationConfig.navigation = navigation;
    }

    static closeDrawer() {
        if (NavigationConfig.navigation) {
            NavigationConfig.navigation.dispatch(DrawerActions.closeDrawer());
        }
    }

    static openDrawer() {
        if (NavigationConfig.navigation) {
            NavigationConfig.navigation.dispatch(DrawerActions.openDrawer());
        }
    }

    static navigate(route = "", params = {}) {
        if (NavigationConfig.navigation) {
            return NavigationConfig.navigation.navigate(route, params);
        }
        throw new Error(`impossible to navigation to ${route}, navigation is invalid`);
    }
}

export { getActiveRouteFromState };
export default NavigationConfig;
