import Logger from "../utils/log";

class EventRegister {
    static #_Listeners = {
        count: 0,
        refs: {}
    };

    static #_addEventListener(eventName, callback) {
        if (typeof eventName === "string" && typeof callback === "function") {
            EventRegister.#_Listeners.count += 1;
            const eventId = `l${EventRegister.#_Listeners.count}`;
            EventRegister.#_Listeners.refs[eventId] = {
                name: eventName,
                callback
            };
            return eventId;
        }
        return false;
    }

    static #_removeEventListener(id) {
        if (typeof id === "string") {
            EventRegister.#_log(`EventsManager removing listener with id: ${id}`);
            return delete EventRegister.#_Listeners.refs[id];
        }
        return false;
    }

    static #_removeAllListeners() {
        let removeError = false;
        EventRegister.#_log("EventsManager remove all listener");
        Object.keys(EventRegister.#_Listeners.refs).forEach((_id) => {
            const removed = delete EventRegister.#_Listeners.refs[_id];
            removeError = !removeError ? !removed : removeError;
        });
        return !removeError;
    }

    static #_emitEvent(eventName, data) {
        EventRegister.#_log(`EventsManager trying to emit event: ${eventName}`);
        Object.keys(EventRegister.#_Listeners.refs).forEach((_id) => {
            if (EventRegister.#_Listeners.refs[_id] && eventName === EventRegister.#_Listeners.refs[_id].name) {
                EventRegister.#_log(
                    `EventsManager emit event: ${eventName}, listener: ${_id}, callback: ${
                        EventRegister.#_Listeners.refs[_id].callback.name || "anonymous"
                    }`
                );
                EventRegister.#_Listeners.refs[_id].callback(data);
            }
        });
    }

    static #_log(message) {
        if (EventRegister.debug) {
            Logger.debug(message);
        }
    }

    static on(eventName, callback) {
        return EventRegister.#_addEventListener(eventName, callback);
    }

    static rm(id) {
        return EventRegister.#_removeEventListener(id);
    }

    static rmAll() {
        return EventRegister.#_removeAllListeners();
    }

    static emit(eventName, data) {
        EventRegister.#_emitEvent(eventName, data);
    }
}

export { EventRegister };
