import Storage from "../utils/storage";

/**
 * This is an entry point for all index-related calls.
 * This class is used to call service to get data, and manager to store that data in AsyncStorage
 */
const LANGUAGE_PACK_BASE_STORAGE_NAME = "languagePack";

export default class LocaleHelper {
    static SP = {
        name: LANGUAGE_PACK_BASE_STORAGE_NAME,
        keys: {
            strings: "strings",
            filetime: "filetime"
        }
    };

    static setStorageName(prefix) {
        let storageName = LANGUAGE_PACK_BASE_STORAGE_NAME;
        if (prefix) {
            storageName = `${prefix}_${storageName}`;
        }
        LocaleHelper.SP.name = storageName;
    }

    static async getItem(key) {
        return Storage.getItem(LocaleHelper.SP.name, key);
    }

    static async setItem(key, value) {
        await Storage.setItem(LocaleHelper.SP.name, key, value);
    }

    static async getFiletime() {
        const filetime = parseInt((await LocaleHelper.getItem(LocaleHelper.SP.keys.filetime)) || -1, 10);
        return filetime;
    }

    static async setFiletime(filetime) {
        return LocaleHelper.setItem(LocaleHelper.SP.keys.filetime, `${filetime}`);
    }

    static async getLanguagePack(): Object {
        const strings = await LocaleHelper.getItem(LocaleHelper.SP.keys.strings);
        if (strings) {
            try {
                return JSON.parse(strings);
            } catch (e) {}
        }
        return {};
    }

    static async setLanguagePack(strings: Object) {
        return LocaleHelper.setItem(LocaleHelper.SP.keys.strings, JSON.stringify(strings));
    }
}
