import "./utils/polyfill";
/**
 * @format
 */
import React, { useEffect } from "react";
import PropTypes from "prop-types";
import { Linking } from "react-native";
import Container from "./Container";
import * as Methods from "./interfaces/methods";
import * as Models from "./interfaces/models";
import { EventRegister } from "./events/manager";
import Events from "./events/events";
import URI from "./models/uri";
import Message from "./models/message";
import { Provider } from "./components/Css/css";

function Root(props) {
    const { onLocal, onMessage, onClose, externalLinkCallbacks, actionCallbacks, needsCssProvider, ...rest } = props;

    useEffect(() => {
        const onCloseId = EventRegister.on(Events.ON_CLOSE, () => {
            if (typeof onClose === "function") {
                onClose();
            }
        });
        const onLocalId = EventRegister.on(Events.WEBVIEW_ON_LOCAL, (obj: { uri: URI, jsInjection: Function }) => {
            if (typeof onLocal === "function") {
                onLocal(obj);
            }
        });
        const onMessageId = EventRegister.on(
            Events.WEBVIEW_ON_MESSAGE,
            (obj: { message: Message, jsInjection: Function }) => {
                if (typeof onMessage === "function") {
                    onMessage(obj);
                }
            }
        );
        const onExternalLinkClickId = EventRegister.on(Events.ON_EXTERNAL_LINK_CLICK, ({ url }) => {
            if (externalLinkCallbacks && typeof externalLinkCallbacks.onClick === "function") {
                externalLinkCallbacks.onClick(url);
            } else {
                Linking.openURL(url);
            }
        });
        const onActionClickId = EventRegister.on(Events.ON_ACTION_CLICK, ({ action }) => {
            if (actionCallbacks && typeof actionCallbacks.onClick === "function") {
                actionCallbacks.onClick(action);
            }
        });

        return () => {
            EventRegister.rm(onLocalId);
            EventRegister.rm(onMessageId);
            EventRegister.rm(onExternalLinkClickId);
            EventRegister.rm(onCloseId);
            EventRegister.rm(onActionClickId);
        };
    }, []);

    const Component = <Container {...rest} />;
    if (needsCssProvider) {
        return <Provider>{Component}</Provider>;
    }

    return Component;
}

Root.propTypes = {
    onClose: PropTypes.func.isRequired,
    onLocal: PropTypes.func,
    onMessage: PropTypes.func,
    externalLinkCallbacks: PropTypes.shape({
        onClick: PropTypes.func
    }),
    actionCallbacks: PropTypes.shape({
        onClick: PropTypes.func
    }),
    needsCssProvider: PropTypes.bool,
    ...Container.propTypes
};

Root.defaultProps = {
    needsCssProvider: true
};

export { Methods, Models };
export default Root;
