import { Image } from "react-native";
import LiveConfig from "../data/live-config";
import { getLowUrl } from "./api";
import Logger from "./log";

async function getImageSize(url): Promise<{ width: Number, height: Number }> {
    if (url) {
        return new Promise((resolve, reject) => {
            Image.getSize(
                url,
                (width, height) => {
                    resolve({ width, height });
                },
                (error) => {
                    reject(error);
                }
            );
        });
    }
    return Promise.reject(new Error("url is required"));
}

async function getIssueAspectRatio(issue) {
    let { aspectRatio } = LiveConfig.getSettings();
    try {
        if (issue) {
            const size = await getImageSize(getLowUrl(issue));
            aspectRatio = size.width / size.height;
            LiveConfig.getSettings().setAspectRatio(aspectRatio);
        }
    } catch (e) {
        ({ aspectRatio } = LiveConfig.getSettings());
        Logger.warn(e);
    }
    return aspectRatio;
}

export { getImageSize, getIssueAspectRatio };
