export default class Logger {
    static #_listeners: {
        onLog: Function,
        onDebug: Function,
        onWarning: Function,
        onError: Function
    } = {};

    static addListeners(callbacks = {}) {
        Logger.#_listeners = callbacks;
        return {
            remove: Logger.#_remove
        };
    }

    static #_remove() {
        Logger.#_listeners = {};
    }

    static log(message, ...rest) {
        Logger.#_callListener("onLog", message, ...rest);
    }

    static debug(message, ...rest) {
        Logger.#_callListener("onDebug", message, ...rest);
    }

    static warn(message, ...rest) {
        Logger.#_callListener("onWarning", message, ...rest);
    }

    static error(message, ...rest) {
        Logger.#_callListener("onError", message, ...rest);
    }

    static #_callListener(listenerKey, message, ...rest) {
        if (typeof Logger.#_listeners[listenerKey] === "function") {
            Logger.#_listeners[listenerKey](message, ...rest);
        }
    }
}
