import NetInfo from "@react-native-community/netinfo";

const HTTP_DOMAIN_SEPARATOR = ".";
const HTTPS_DOMAIN_SEPARATOR = "-";

class Network {
    static DEFAULT_PROTOCOLS = ["http", "https"];
    static isHTTPS = true;
    static connectionInfo = { type: "unknown", effectiveType: "unknown" };
    static IP = "n/a";

    static addDefaultProtocol(url) {
        let newUrl = url;
        const result = Network.DEFAULT_PROTOCOLS.find((protocol) => url.startsWith(protocol));
        if (!result) {
            const protocol = Network.isHTTPS ? "https" : "http";
            newUrl = `${protocol}:`;
            if (!url.startsWith("//")) {
                newUrl += "//";
            }
            newUrl += url;
        }
        return newUrl;
    }

    static addConnectionChangeEventListener(callback) {
        if (callback) {
            Network.removeConnectionChangeEventListener();
            Network.eventListener = NetInfo.addEventListener((state) => {
                Network.connectionInfo = Network.returnConnectionInfo(state);
                callback(Network.connectionInfo);
            });
        }
    }

    static removeConnectionChangeEventListener() {
        if (Network.eventListener) {
            Network.eventListener();
        }
    }

    static returnConnectionInfo(state) {
        const { type, details, isInternetReachable } = state;
        let effectiveType = "unknown";
        if (details && details.cellularGeneration) {
            effectiveType = details.cellularGeneration;
        }
        return { type, effectiveType, isInternetReachable };
    }

    static async getConnectionInfo() {
        try {
            const state = await NetInfo.fetch();
            Network.connectionInfo = Network.returnConnectionInfo(state);
            return Network.connectionInfo;
        } catch (e) {}

        return { type: "unknown", effectiveType: "unknown", isInternetReachable: null };
    }

    static isOnline() {
        //the values are experimental, so sometimes doesn't are correct
        if (Network.connectionInfo) {
            const { type, isInternetReachable } = Network.connectionInfo;
            return type !== "none" && type !== "unknown" && isInternetReachable !== false;
        }
        return false;
    }

    static isInternetReachable() {
        if (Network.connectionInfo) {
            return Network.connectionInfo.isInternetReachable !== false;
        }
        return false;
    }

    static isWiFi() {
        if (Network.connectionInfo) {
            return Network.connectionInfo.type === "wifi";
        }
        return false;
    }

    static isCellular() {
        if (Network.connectionInfo) {
            return Network.connectionInfo.type === "cellular";
        }
        return false;
    }

    static isHighSpeedNetwork() {
        return Network.isWiFi() || Network.is4G();
    }

    static is2G() {
        return Network.isCellularOnBand("2g");
    }

    static is3G() {
        return Network.isCellularOnBand("3g");
    }

    static is4G() {
        return Network.isCellularOnBand("4g");
    }

    static isCellularOnBand(band) {
        if (Network.connectionInfo) {
            return Network.connectionInfo.type === "cellular" && Network.connectionInfo.effectiveType === band;
        }
        return false;
    }

    static getIP() {
        return Network.IP;
    }

    static setIP(ip) {
        Network.IP = ip;
    }

    static isTecnaviaIP() {
        return Network.IP.startsWith("82.220.");
    }
}

export { HTTPS_DOMAIN_SEPARATOR, HTTP_DOMAIN_SEPARATOR };
export default Network;
