const { dependencies = {}, peerDependencies = {} } = require("./package.json");
const { resolveAppPath } = require("./webpack.utils");

const dependenciesModules = Object.keys(dependencies).map((moduleName) => {
    return resolveAppPath(`node_modules/${moduleName}`);
});
const peerDependenciesModules = Object.keys(peerDependencies).map((moduleName) => {
    return resolveAppPath(`node_modules/${moduleName}`);
});
const compileNodeModules = [...dependenciesModules, ...peerDependenciesModules];

// This is needed for webpack to compile JavaScript.
// Many OSS React Native packages are not compiled to ES5 before being
// published. If you depend on uncompiled packages they may cause webpack build
// errors. To fix this webpack can be configured to compile to the necessary
// `node_module`.
const babelLoader = (isProduction = false) => {
    console.debug(`Using babel in production mode: ${isProduction}`);
    const plugins = [
        ["react-native-web"],
        "@babel/plugin-syntax-dynamic-import",
        ["@babel/plugin-proposal-private-methods", { loose: true }]
    ];
    if (isProduction) {
        plugins.push("transform-react-remove-prop-types");
    }
    return {
        test: /\.js$/,
        // Add every directory that needs to be compiled by Babel during the build.
        include: [resolveAppPath("index.web.js"), resolveAppPath("src"), ...compileNodeModules],
        use: {
            loader: "babel-loader",
            options: {
                cacheDirectory: true,
                configFile: false,
                // The 'metro-react-native-babel-preset' preset is recommended to match React Native's packager
                presets: ["module:metro-react-native-babel-preset"],
                // Re-write paths to import only the modules needed by the app
                plugins
            }
        }
    };
};

module.exports = babelLoader;
