/* eslint-disable import/no-extraneous-dependencies */
// web/webpack.config.js
const webpack = require("webpack");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const InterpolateHtmlPlugin = require("interpolate-html-plugin");
const { WebpackManifestPlugin } = require("webpack-manifest-plugin");
const MomentLocalesPlugin = require("moment-locales-webpack-plugin");
const { resolveAppPath } = require("./webpack.utils");
const { version } = require("./package.json");

const cssLoader = {
    test: /\.css$/i,
    use: ["style-loader", "css-loader"]
};

// This is needed for webpack to import static images in JavaScript files.
const imageLoader = {
    test: /\.(ttf|gif|jpe?g|png|svg|ico)$/,
    use: {
        loader: "url-loader",
        options: {
            name: "[name].[ext]",
            esModule: false
        }
    }
};

module.exports = {
    entry: [resolveAppPath("index.web.js")],
    // configures where the build ends up
    output: {
        filename: "ta-options-page.js",
        // `chunkFilename` provides a template for naming code-split bundles (optional)
        chunkFilename: "[name].bundle.js",
        path: resolveAppPath("dist"),
        library: "TaOptionsPage",
        libraryTarget: "umd",
        clean: true
    },
    module: {
        rules: [cssLoader, imageLoader]
    },
    resolve: {
        // This will only alias the exact import "react-native"
        alias: {
            "react-native$": "react-native-web",
            "react-native-linear-gradient": "react-native-web-linear-gradient"
        },
        // If you're working on a multi-platform React Native app, web-specific
        // module implementations should be written in files using the extension
        // `.web.js`.
        extensions: [".web.js", ".js", ".tsx", ".ts"]
    },
    plugins: [
        new webpack.DefinePlugin({
            // See: https://github.com/necolas/react-native-web/issues/349
            __DEV__: JSON.stringify(true)
        }),
        new webpack.ProvidePlugin({
            process: "process/browser"
        }),
        new WebpackManifestPlugin({}),
        new InterpolateHtmlPlugin({
            PUBLIC_URL: "public" // can modify `static` to another name or get it from `process`
        }),
        new HtmlWebpackPlugin({
            template: resolveAppPath("public/index.html"),
            favicon: resolveAppPath("public/favicon.ico"),
            inject: "head",
            scriptLoading: "blocking"
        }),
        new MomentLocalesPlugin({
            localesToKeep: ["ar", "it", "da", "de", "fr", "nl", "es", "ro", "sv", "pt", "pt-br", "nl-be", "nn", "nb"]
        })
    ]
};
